@@ -16,15 +16,9 @@ double Counter::Value() const { return gauge_.Value(); }
 void Counter::Reset() { gauge_.Set(0); }
 
 ClientMetric Counter::Collect() const {
-  if (collect_callback_ != nullptr) return collect_callback_();
-
   ClientMetric metric;
   metric.counter.value = Value();
   return metric;
 }
 
-void Counter::AddCollectCallback(CollectCallbackPtr cb) {
-  collect_callback_ = std::move(cb);
-}
-
 }  // namespace prometheus
