@@ -7,6 +7,7 @@
 #include "caf/default_enum_inspect.hpp"
 #include "caf/detail/core_export.hpp"
 
+#include <string_view>
 #include <type_traits>
 
 namespace caf::async {
@@ -28,7 +29,7 @@ enum class write_result {
 CAF_CORE_EXPORT std::string to_string(write_result);
 
 /// @relates write_result
-CAF_CORE_EXPORT bool from_string(string_view, write_result&);
+CAF_CORE_EXPORT bool from_string(std::string_view, write_result&);
 
 /// @relates write_result
 CAF_CORE_EXPORT bool from_integer(std::underlying_type_t<write_result>,
