@@ -26,11 +26,14 @@ int main() {
   for (int n = 0; n < 5; n++) {
     // Wait for a "ping" event.
     auto msg = sub.get();
-    zeek::Event ping(move_data(msg));
-    std::cout << "received " << ping.name() << ping.args() << std::endl;
+    auto ping = zeek::Event{std::move(msg)};
+    if (ping.valid())
+      std::cout << "received " << ping.name() << ping.args() << std::endl;
+    else
+      std::cout << "received invalid ping message: " << to_string(ping)
+                << std::endl;
 
     // Send event "pong" response.
-    zeek::Event pong("pong", {n});
-    ep.publish("/topic/test", pong);
+    ep.publish("/topic/test", zeek::Event{"pong", {n}});
   }
 }
