@@ -184,11 +184,17 @@ wait_thread_loop(UNUSED void *arg)
     sigset_t sigmask;
     struct proc_pid *ppd, *ppd_tmp;
 
+#ifdef __linux__
     /* Set the thread's name to something descriptive so it shows up in gdb,
      * etc. Max name length is 16 bytes. */
     prctl(PR_SET_NAME, "libkqueue_wait", 0, 0, 0);
-
     proc_wait_tid = syscall(SYS_gettid);
+#else
+    /*
+     *  There's no POSIX interface for getting a numeric thread ID
+     */
+    proc_wait_tid = 1;
+#endif
 
     dbg_printf("tid=%u - waiter thread started", proc_wait_tid);
 
@@ -282,16 +288,22 @@ wait_thread_loop(UNUSED void *arg)
     pthread_cond_signal(&proc_wait_thread_cond);
     pthread_mutex_unlock(&proc_wait_thread_mtx);
     do {
+        /*
+         * Check for errors before altering the cancellation
+         * state, so we don't end up calling sigwaitinfo
+         * with the cancellations disabled.
+         */
+        if (ret < 0) {
+            dbg_printf("sigwaitinfo(2): %s", strerror(errno));
+            continue;
+        }
+
         /*
          * Don't allow the thread to be cancelled until we've
          * finished one loop in the monitoring thread.  This
          * ensures there are no nasty issue on exit.
          */
         pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-        if (ret < 0) {
-            dbg_printf("sigwaitinfo(2): %s", strerror(errno));
-            continue;
-        }
 
         /*
          * The knote_* functions (i.e. those that could free a
