@@ -101,7 +101,7 @@ test_cleanup(void *unused)
     }
 
     /* lower FD limit to 32 */
-    if (max_fds < rlim.rlim_cur) {
+    if (max_fds < curr_rlim.rlim_cur) {
         /* Set FD limit to MAX_FDS */
         rlim = curr_rlim;
         rlim.rlim_cur = 32;
@@ -109,7 +109,7 @@ test_cleanup(void *unused)
             die("setrlimit failed");
         }
     } else {
-        max_fds = rlim.rlim_cur;
+        max_fds = curr_rlim.rlim_cur;
     }
 
     /* Create initial kqueue to avoid cleanup thread being destroyed on each close */
