@@ -13,11 +13,11 @@
 
 #include <algorithm>
 #include <initializer_list>
-#include <memory>
 #include <set>
 #include <string>
 #include <utility>
 
+#include <hilti/rt/exception.h>
 #include <hilti/rt/extension-points.h>
 #include <hilti/rt/iterator.h>
 #include <hilti/rt/safe-int.h>
@@ -33,26 +33,29 @@ template<typename T>
 class Iterator {
     using S = Set<T>;
 
-    std::weak_ptr<S*> _control;
-    typename S::V::iterator _iterator;
+    using Control = typename S::Control::Ref;
+    Control _control;
+    typename S::S::iterator _iterator;
 
 public:
+    using iterator_category = typename S::S::iterator::iterator_category;
+    using value_type = typename S::S::value_type;
+    using difference_type = typename S::S::difference_type;
+    using pointer = typename S::S::pointer;
+    using reference = typename S::S::reference;
+
     Iterator() = default;
 
     typename S::reference operator*() const {
-        if ( auto&& l = _control.lock() ) {
-            // Iterators to `end` cannot be dereferenced.
-            if ( _iterator == static_cast<const std::set<T>&>(**l).end() )
-                throw IndexError("iterator is invalid");
+        // Iterators to `end` cannot be dereferenced.
+        if ( _iterator == static_cast<const std::set<T>&>(_control.get()).end() )
+            throw IndexError("iterator is invalid");
 
-            return *_iterator;
-        }
-
-        throw IndexError("iterator is invalid");
+        return *_iterator;
     }
 
     Iterator& operator++() {
-        if ( ! _control.lock() )
+        if ( ! _control.isValid() )
             throw IndexError("iterator is invalid");
 
         ++_iterator;
@@ -66,7 +69,7 @@ public:
     }
 
     friend bool operator==(const Iterator& a, const Iterator& b) {
-        if ( a._control.lock() != b._control.lock() )
+        if ( a._control != b._control )
             throw InvalidArgument("cannot compare iterators into different sets");
 
         return a._iterator == b._iterator;
@@ -77,8 +80,8 @@ public:
 protected:
     friend class Set<T>;
 
-    Iterator(typename S::V::iterator iterator, const typename S::C& control)
-        : _control(control), _iterator(std::move(iterator)) {}
+    Iterator(typename S::S::iterator iterator, Control control)
+        : _control(std::move(control)), _iterator(std::move(iterator)) {}
 };
 
 } // namespace set
@@ -107,10 +110,10 @@ protected:
 template<typename T>
 class Set : protected std::set<T> {
 public:
-    using V = std::set<T>;
-    using C = std::shared_ptr<Set<T>*>;
+    using S = std::set<T>;
 
-    C _control = std::make_shared<Set<T>*>(this);
+    using Control = control::Block<Set<T>, InvalidIterator>;
+    Control _control{this};
 
     using reference = const T&;
     using const_reference = const T&;
@@ -140,10 +143,15 @@ public:
      */
     bool contains(const T& t) const { return this->count(t); }
 
-    auto begin() const { return iterator(static_cast<const V&>(*this).begin(), empty() ? nullptr : _control); }
-    auto end() const { return iterator(static_cast<const V&>(*this).end(), empty() ? nullptr : _control); }
+    auto begin() const {
+        return iterator(static_cast<const S&>(*this).begin(), empty() ? typename Control::Ref() : _control);
+    }
 
-    size_type size() const { return V::size(); }
+    auto end() const {
+        return iterator(static_cast<const S&>(*this).end(), empty() ? typename Control::Ref() : _control);
+    }
+
+    size_type size() const { return S::size(); }
 
     /** Removes an element from the set.
      *
@@ -154,9 +162,9 @@ public:
      */
     size_type erase(const key_type& key) {
         // Update control block to invalidate all iterators previously created from it.
-        _control = std::make_shared<Set<T>*>();
+        _control.Reset();
 
-        return static_cast<V&>(*this).erase(key);
+        return static_cast<S&>(*this).erase(key);
     }
 
     /** Erases all elements from the set.
@@ -165,9 +173,9 @@ public:
      */
     void clear() {
         // Update control block to invalidate all iterators previously created from it.
-        _control = std::make_shared<Set<T>*>();
+        _control.Reset();
 
-        return static_cast<V&>(*this).clear();
+        return static_cast<S&>(*this).clear();
     }
 
     /** Inserts value in the position as close as possible to hint.
@@ -177,15 +185,19 @@ public:
      * @return iterator pointing to the inserted element
      * */
     iterator insert(iterator hint, const T& value) {
-        auto it = V::insert(hint._iterator, value);
+        auto it = S::insert(hint._iterator, value);
         return iterator(it, _control);
     }
 
-    // Methods of `std::set`. These methods *must not* cause any iterator invalidation.
-    using V::empty;
-    using V::insert;
+    std::pair<iterator, bool> insert(const T& value) {
+        auto [it, inserted] = S::insert(value);
+        return {iterator(it, _control), inserted};
+    }
 
-    friend bool operator==(const Set& a, const Set& b) { return static_cast<const V&>(a) == static_cast<const V&>(b); }
+    // Methods of `std::set`. These methods *must not* cause any iterator invalidation.
+    using S::empty;
+
+    friend bool operator==(const Set& a, const Set& b) { return static_cast<const S&>(a) == static_cast<const S&>(b); }
     friend bool operator!=(const Set& a, const Set& b) { return ! (a == b); }
 
     friend set::Iterator<T>;
@@ -252,4 +264,5 @@ inline std::ostream& operator<<(std::ostream& out, const Iterator<T>& x) {
     return out;
 }
 } // namespace set
+
 } // namespace hilti::rt
