@@ -494,11 +494,11 @@ TEST_CASE("toReal") {
 
     // The next test should fail independent of the locale, so let's set one.
 
-    auto de_locale = newlocale(LC_ALL_MASK, "de_DE.UTF-8", nullptr);
+    auto* de_locale = newlocale(LC_ALL_MASK, "de_DE.UTF-8", nullptr);
     if ( ! de_locale )
         FAIL("failed to create de_DE locale; locales not installed?");
 
-    auto old_locale = uselocale(de_locale);
+    auto* old_locale = uselocale(de_locale);
     CHECK_THROWS_WITH_AS("1,0"_b.toReal(), "cannot parse real value: '1,0'", const InvalidValue&);
     uselocale(old_locale);
 
@@ -584,14 +584,14 @@ TEST_CASE("assign") {
     SUBCASE("rvalue") {
         b = "abc"_b;
         CHECK_EQ(to_string(b), "b\"abc\"");
-        CHECK_THROWS_WITH_AS(*it, "bound object has expired", const InvalidIterator&);
+        CHECK_THROWS_WITH_AS(*it, "underlying object has expired", const InvalidIterator&);
     }
 
     SUBCASE("lvalue") {
         const auto bb = "abc"_b;
         b = bb;
         CHECK_EQ(to_string(b), "b\"abc\"");
-        CHECK_THROWS_WITH_AS(*it, "bound object has expired", const InvalidIterator&);
+        CHECK_THROWS_WITH_AS(*it, "underlying object has expired", const InvalidIterator&);
     }
 }
 
@@ -603,7 +603,7 @@ TEST_CASE("Iterator") {
         CHECK_NOTHROW(*b.begin()); // Iterator valid since container is alife.
 
         auto it = ""_b.begin();
-        CHECK_THROWS_WITH_AS(*it, "bound object has expired", const InvalidIterator&);
+        CHECK_THROWS_WITH_AS(*it, "underlying object has expired", const InvalidIterator&);
     }
 
     SUBCASE("increment") {
