@@ -1,4 +1,4 @@
-// Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.
+// Copyright (c) 2020-now by the Zeek Project. See LICENSE for details.
 
 #include <memory>
 #include <utility>
@@ -35,31 +35,17 @@ TEST_SUITE_BEGIN("hilti");
 TEST_CASE("print") {
     SUBCASE("w/ newline") {
         TestCout cout;
-        print("\x00\x01"_b, true);
-        print(0.5, true);
+        print("\x00\x01"_b, nullptr, true);
+        print(0.5, nullptr, true);
         CHECK_EQ(cout.str(), "\\x00\\x01\n0.5\n");
     }
 
     SUBCASE("w/o newline") {
         TestCout cout;
-        print("\x00\x01"_b, false);
-        print(0.5, false);
+        print("\x00\x01"_b, nullptr, false);
+        print(0.5, nullptr, false);
         CHECK_EQ(cout.str(), "\\x00\\x010.5");
     }
 }
 
-TEST_CASE("printValues") {
-    SUBCASE("w/ newline") {
-        TestCout cout;
-        printValues(std::make_tuple("\x00\x01"_b, 0.5), true);
-        CHECK_EQ(cout.str(), "\\x00\\x01, 0.5\n");
-    }
-
-    SUBCASE("w/o newline") {
-        TestCout cout;
-        printValues(std::make_tuple("\x00\x01"_b, 0.5), false);
-        CHECK_EQ(cout.str(), "\\x00\\x01, 0.5");
-    }
-}
-
 TEST_SUITE_END();
