@@ -102,6 +102,14 @@ options = [
         "The TCP port number that Zeek will listen on. For a cluster configuration, each node in the cluster will automatically be assigned a subsequent port to listen on.",
         "BroPort",
     ),
+    Option(
+        "MetricsAddress",
+        "0.0.0.0",
+        "string",
+        Option.USER,
+        False,
+        "The address on which the Prometheus HTTP server listens on (Telemetry::metrics_address).",
+    ),
     Option(
         "MetricsPort",
         9991,
