@@ -5,10 +5,12 @@ import os
 cflags = os.environ.get("CFLAGS", "")
 os.environ["CFLAGS"] = cflags + " -fno-strict-aliasing"
 
-from setuptools import Extension, setup
+from distutils.core import Extension
+
+from setuptools import setup
 
 setup(
-    version="0.38.1",  # Filled in automatically.
+    version="0.37.dev28",  # Filled in automatically.
     py_modules=["SubnetTree"],
     url="https://github.com/zeek/pysubnettree",
     ext_modules=[
