@@ -1,3 +1,4 @@
+#include <cmath>
 #include <limits>
 
 #include "Plugin.h"
@@ -106,12 +107,22 @@ ZeekValWrapper::ZeekValWrapper(v8::Isolate* isolate) : isolate_(isolate) {
   v8::Local<v8::ObjectTemplate> record_template = v8::ObjectTemplate::New(isolate_);
   record_template->SetInternalFieldCount(1);
   record_template->SetPrivate(GetWrapPrivateKey(isolate), v8::True(isolate),
-                              v8::PropertyAttribute::DontEnum);
+                              v8::PropertyAttribute(v8::PropertyAttribute::DontEnum |
+                                                    v8::PropertyAttribute::DontDelete |
+                                                    v8::PropertyAttribute::ReadOnly));
 
   v8::NamedPropertyHandlerConfiguration record_conf =
-      v8::NamedPropertyHandlerConfiguration(ZeekRecordGetter, ZeekRecordSetter,
-                                            ZeekRecordQuery, nullptr /* deleter */,
-                                            ZeekRecordEnumerator);
+      v8::NamedPropertyHandlerConfiguration(
+          /*getter=*/ZeekRecordGetter,
+          /*setter=*/ZeekRecordSetter,
+          /*query=*/ZeekRecordQuery,
+          /*deleter=*/nullptr,
+          /*enumerator=*/ZeekRecordEnumerator,
+          /*definer=*/nullptr,
+          /*descriptor=*/nullptr,
+          /*data=*/v8::Local<v8::Value>(),
+          /*flags=*/v8::PropertyHandlerFlags::kHasNoSideEffect);
+
   record_template->SetHandler(record_conf);
   record_template_.Reset(isolate_, record_template);
 
@@ -155,8 +166,13 @@ ZeekValWrapper::ZeekValWrapper(v8::Isolate* isolate) : isolate_(isolate) {
                         v8::SideEffectType::kHasNoSideEffect)
           .ToLocalChecked());
 
+#if (NODE_MAJOR_VERSION <= 22)
   v8::AccessorGetterCallback toJSON_cb =
       [](v8::Local<v8::String> property,
+#else
+  v8::AccessorNameGetterCallback toJSON_cb =
+      [](v8::Local<v8::Name> property,
+#endif
          const v8::PropertyCallbackInfo<v8::Value>& info) {
         info.GetReturnValue().Set(info.This()->GetInternalField(2).As<v8::Value>());
       };
@@ -165,31 +181,49 @@ ZeekValWrapper::ZeekValWrapper(v8::Isolate* isolate) : isolate_(isolate) {
       v8_str_intern("toJSON"), toJSON_cb, nullptr, v8::Local<v8::Value>(),
       v8::PropertyAttribute(v8::PropertyAttribute::DontEnum |
                             v8::PropertyAttribute::ReadOnly),
+#if (NODE_MAJOR_VERSION <= 22)
+      v8::AccessControl::DEFAULT,
+#endif
+      v8::SideEffectType::kHasNoSideEffect);
 
-      v8::AccessControl::DEFAULT, v8::SideEffectType::kHasNoSideEffect);
-
+#if (NODE_MAJOR_VERSION <= 22)
   v8::AccessorGetterCallback port_cb =
       [](v8::Local<v8::String> property,
+#else
+  v8::AccessorNameGetterCallback port_cb =
+      [](v8::Local<v8::Name> property,
+#endif
          const v8::PropertyCallbackInfo<v8::Value>& info) {
         info.GetReturnValue().Set(info.This()->GetInternalField(0).As<v8::Value>());
       };
 
-  port_template->SetNativeDataProperty(
-      v8_str_intern("port"), port_cb, nullptr, v8::Local<v8::Value>(),
-      v8::PropertyAttribute::ReadOnly, v8::AccessControl::DEFAULT,
-      v8::SideEffectType::kHasNoSideEffect);
+  port_template->SetNativeDataProperty(v8_str_intern("port"), port_cb, nullptr,
+                                       v8::Local<v8::Value>(),
+                                       v8::PropertyAttribute::ReadOnly,
+#if (NODE_MAJOR_VERSION <= 22)
+                                       v8::AccessControl::DEFAULT,
+#endif
+                                       v8::SideEffectType::kHasNoSideEffect);
 
+#if (NODE_MAJOR_VERSION <= 22)
   v8::AccessorGetterCallback proto_cb =
       [](v8::Local<v8::String> property,
+#else
+  v8::AccessorNameGetterCallback proto_cb =
+      [](v8::Local<v8::Name> property,
+#endif
          const v8::PropertyCallbackInfo<v8::Value>& info) {
         info.GetIsolate();
         info.GetReturnValue().Set(info.This()->GetInternalField(1).As<v8::Value>());
       };
 
-  port_template->SetNativeDataProperty(
-      v8_str_intern("proto"), proto_cb, nullptr, v8::Local<v8::Value>(),
-      v8::PropertyAttribute::ReadOnly, v8::AccessControl::DEFAULT,
-      v8::SideEffectType::kHasNoSideEffect);
+  port_template->SetNativeDataProperty(v8_str_intern("proto"), proto_cb, nullptr,
+                                       v8::Local<v8::Value>(),
+                                       v8::PropertyAttribute::ReadOnly,
+#if (NODE_MAJOR_VERSION <= 22)
+                                       v8::AccessControl::DEFAULT,
+#endif
+                                       v8::SideEffectType::kHasNoSideEffect);
   port_template_.Reset(isolate_, port_template);
 
   port_str_.Reset(isolate, v8_str_intern("port"));
@@ -646,20 +680,106 @@ ZeekValWrapper::Result ZeekValWrapper::ToZeekVal(v8::Local<v8::Value> v8_val,
     }
   } else if (type_tag == zeek::TYPE_COUNT) {
     if (v8_val->IsNumber()) {
-      v8::MaybeLocal<v8::Uint32> result = v8_val->ToUint32(context);
-      wrap_result.val = zeek::val_mgr->Count(result.ToLocalChecked()->Value());
-      return wrap_result;
+      double dresult = v8_val->NumberValue(context).ToChecked();
+
+      // If this is a positive number, convert it to a double, then cast
+      // to a zeek_uint_t for the val manager. Convert the unsigned
+      // int to a double before to see if we get the same result,
+      // otherwise report precision loss.
+      //
+      // NOTE: This is subtracting 2048 from zeek_uint_t's max value
+      // to avoid platform specific differences when casting between
+      // zeek_uint_t and double on Linux vs OSX when close at the limit.
+      //
+      // If you understand, patches certainly welcome to remove the 2048!
+      if (std::isfinite(dresult) &&
+          dresult <=
+              static_cast<double>(std::numeric_limits<zeek_uint_t>::max() - 2048) &&
+          dresult >= 0.0) {
+        auto result = static_cast<zeek_uint_t>(dresult);
+        auto diresult = static_cast<double>(result);
+        // No fractional part?
+        if (dresult == diresult) {
+          wrap_result.val = zeek::val_mgr->Count(result);
+        } else {
+          v8::String::Utf8Value val_utf8(isolate_, v8_val);
+          wrap_result.ok = false;
+          wrap_result.error =
+              zeek::util::fmt("precision loss going from %s to count", *val_utf8);
+        }
+
+        return wrap_result;
+      }
     } else if (v8_val->IsBigInt()) {
-      v8::MaybeLocal<v8::BigInt> result = v8_val->ToBigInt(context);
-      wrap_result.val = zeek::val_mgr->Count(result.ToLocalChecked()->Uint64Value());
-      return wrap_result;
+      bool lossless = true;
+      auto bigint = v8_val->ToBigInt(context).ToLocalChecked();
+      zeek_uint_t result = bigint->Uint64Value(&lossless);
+
+      if (lossless) {
+        wrap_result.val = zeek::val_mgr->Count(result);
+        return wrap_result;
+      } else {
+        v8::String::Utf8Value val_utf8(isolate_, v8_val);
+        wrap_result.ok = false;
+        wrap_result.error =
+            zeek::util::fmt("precision loss going from %s to count", *val_utf8);
+        return wrap_result;
+      }
     }
+
+    // Generic error
+    wrap_result.ok = false;
+    v8::String::Utf8Value val_utf8(isolate_, v8_val);
+    wrap_result.error = zeek::util::fmt(
+        "'%s' not a number or bigint or out of range for count", *val_utf8);
+    return wrap_result;
   } else if (type_tag == zeek::TYPE_INT) {
     if (v8_val->IsNumber()) {
-      v8::MaybeLocal<v8::Int32> result = v8_val->ToInt32(context);
-      wrap_result.val = zeek::val_mgr->Int(result.ToLocalChecked()->Value());
+      double dresult = v8_val->NumberValue(context).ToChecked();
+
+      if (std::isfinite(dresult) &&
+          dresult <= static_cast<double>(std::numeric_limits<zeek_int_t>::max()) &&
+          dresult >= static_cast<double>(std::numeric_limits<zeek_int_t>::min())) {
+        // Cast to zeek_int_t, then cast once more to double and
+        // compare to the original input. If there was any loss,
+        // fail the conversion.
+        zeek_int_t result = v8_val->IntegerValue(context).ToChecked();
+        auto diresult = static_cast<double>(result);
+
+        if (dresult == diresult) {
+          wrap_result.val = zeek::val_mgr->Int(result);
+        } else {
+          v8::String::Utf8Value val_utf8(isolate_, v8_val);
+          wrap_result.ok = false;
+          wrap_result.error =
+              zeek::util::fmt("precision loss going from %s to int", *val_utf8);
+        }
+
+        return wrap_result;
+      }
+    } else if (v8_val->IsBigInt()) {
+      // Try BigInt to int for convenience, but fail if it is too large.
+      bool lossless = true;
+      auto bigint = v8_val->ToBigInt(context).ToLocalChecked();
+      zeek_int_t result = bigint->Int64Value(&lossless);
+
+      if (lossless) {
+        wrap_result.val = zeek::val_mgr->Count(result);
+      } else {
+        v8::String::Utf8Value val_utf8(isolate_, v8_val);
+        wrap_result.ok = false;
+        wrap_result.error =
+            zeek::util::fmt("precision loss going from %s to int", *val_utf8);
+      }
+
       return wrap_result;
     }
+
+    wrap_result.ok = false;
+    v8::String::Utf8Value val_utf8(isolate_, v8_val);
+    wrap_result.error = zeek::util::fmt(
+        "'%s' not a number or bigint or out of range for int", *val_utf8);
+    return wrap_result;
   } else if (type_tag == zeek::TYPE_DOUBLE) {
     if (v8_val->IsNumber()) {
       v8::Maybe<double> result = v8_val->NumberValue(context);
@@ -909,14 +1029,15 @@ ZeekValWrapper::Result ZeekValWrapper::ToZeekVal(v8::Local<v8::Value> v8_val,
   return wrap_result;
 }
 
-void ZeekValWrapper::ZeekTableGetter(v8::Local<v8::Name> property,
-                                     const v8::PropertyCallbackInfo<v8::Value>& info) {
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekTableGetter(
+    v8::Local<v8::Name> property,
+    const v8::PropertyCallbackInfo<v8::Value>& info) {
   v8::Isolate* isolate = info.GetIsolate();
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
       static_cast<ZeekValWrap*>(receiver->GetAlignedPointerFromInternalField(0));
   if (wrap->GetVal()->GetType()->Tag() != zeek::TYPE_TABLE)
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
 
   auto tval = static_cast<zeek::TableVal*>(wrap->GetVal());
 
@@ -924,7 +1045,7 @@ void ZeekValWrapper::ZeekTableGetter(v8::Local<v8::Name> property,
 
   if (!*arg) {
     dprintf("%s", "empty arg?");
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TableTypePtr ttype = tval->GetType<zeek::TableType>();
@@ -937,28 +1058,34 @@ void ZeekValWrapper::ZeekTableGetter(v8::Local<v8::Name> property,
         isolate,
         zeek::util::fmt("Unexpected number of index types: %lu", itypes.size())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TypePtr index_type = itypes[0];
   ZeekValWrapper::Result index_result =
       wrap->GetWrapper()->ToZeekVal(property, index_type);
   if (!index_result.ok)
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
 
   zeek::ValPtr found_val = tval->Find(index_result.val);
   if (!found_val)
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
 
   dprintf("tval=%p ttype=%p itypes=%lu property=%s FOUND", tval, ttype.get(),
           itypes.size(), *arg);
 
   info.GetReturnValue().Set(wrap->GetWrapper()->Wrap(found_val));
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
-void ZeekValWrapper::ZeekTableSetter(v8::Local<v8::Name> property,
-                                     v8::Local<v8::Value> v8_val,
-                                     const v8::PropertyCallbackInfo<v8::Value>& info) {
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekTableSetter(
+    v8::Local<v8::Name> property,
+    v8::Local<v8::Value> v8_val,
+#if (NODE_MAJOR_VERSION <= 22)
+    const v8::PropertyCallbackInfo<v8::Value>& info) {
+#else
+    const v8::PropertyCallbackInfo<void>& info) {
+#endif
   v8::Isolate* isolate = info.GetIsolate();
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
@@ -976,7 +1103,7 @@ void ZeekValWrapper::ZeekTableSetter(v8::Local<v8::Name> property,
         isolate,
         zeek::util::fmt("Unexpected number of index types: %lu", itypes.size())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TypePtr index_type = itypes[0];
@@ -986,7 +1113,7 @@ void ZeekValWrapper::ZeekTableSetter(v8::Local<v8::Name> property,
     v8::Local<v8::Value> error = v8::Exception::TypeError(::v8_str(
         isolate, zeek::util::fmt("Bad index: %s", property_wrap_result.error.c_str())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   ZeekValWrapper::Result value_wrap_result =
@@ -995,13 +1122,14 @@ void ZeekValWrapper::ZeekTableSetter(v8::Local<v8::Name> property,
     v8::Local<v8::Value> error = v8::Exception::TypeError(::v8_str(
         isolate, zeek::util::fmt("Bad value: %s", value_wrap_result.error.c_str())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   // Broker forward is on...
   tval->Assign(property_wrap_result.val, value_wrap_result.val);
 
   info.GetReturnValue().Set(v8_val);
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
 // This is slightly insane - when the Enumerator returns a Name that's
@@ -1009,7 +1137,7 @@ void ZeekValWrapper::ZeekTableSetter(v8::Local<v8::Name> property,
 //
 // Maybe that's not so insane, but that's why we have the below and
 // may convert from Javascript numbers to String keys in Zeek.
-void ZeekValWrapper::ZeekTableIndexGetter(
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekTableIndexGetter(
     uint32_t index,
     const v8::PropertyCallbackInfo<v8::Value>& info) {
   v8::Isolate* isolate = info.GetIsolate();
@@ -1027,7 +1155,7 @@ void ZeekValWrapper::ZeekTableIndexGetter(
         isolate,
         zeek::util::fmt("Unexpected number of index types: %lu", itypes.size())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TypePtr index_type = itypes[0];
@@ -1045,21 +1173,26 @@ void ZeekValWrapper::ZeekTableIndexGetter(
         ::v8_str(isolate, zeek::util::fmt("unable to convert index %d to %s", index,
                                           zeek::type_name(index_type->Tag()))));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::ValPtr val = tval->Find(index_result.val);
   if (!val) {
     eprintf("Failed to lookup value for index=%d", index);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
   info.GetReturnValue().Set(wrap->GetWrapper()->Wrap(val));
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
-void ZeekValWrapper::ZeekTableIndexSetter(
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekTableIndexSetter(
     uint32_t index,
     v8::Local<v8::Value> v8_val,
+#if (NODE_MAJOR_VERSION <= 22)
     const v8::PropertyCallbackInfo<v8::Value>& info) {
+#else
+    const v8::PropertyCallbackInfo<void>& info) {
+#endif
   v8::Isolate* isolate = info.GetIsolate();
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
@@ -1075,7 +1208,7 @@ void ZeekValWrapper::ZeekTableIndexSetter(
         isolate,
         zeek::util::fmt("Unexpected number of index types: %lu", itypes.size())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TypePtr index_type = itypes[0];
@@ -1094,7 +1227,7 @@ void ZeekValWrapper::ZeekTableIndexSetter(
         ::v8_str(isolate, zeek::util::fmt("unable to convert index %d to %s", index,
                                           zeek::type_name(index_type->Tag()))));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   ZeekValWrapper::Result value_wrap_result =
@@ -1103,13 +1236,14 @@ void ZeekValWrapper::ZeekTableIndexSetter(
     v8::Local<v8::Value> error = v8::Exception::TypeError(::v8_str(
         isolate, zeek::util::fmt("Bad value: %s", value_wrap_result.error.c_str())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   // Broker forward is on...
   tval->Assign(index_wrap_result.val, value_wrap_result.val);
 
   info.GetReturnValue().Set(v8_val);
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
 void ZeekValWrapper::ZeekTableEnumerator(
@@ -1174,29 +1308,44 @@ void ZeekValWrapper::ZeekTableEnumerator(
 }
 
 // Callback for looking up properties of a record.
-void ZeekValWrapper::ZeekRecordGetter(v8::Local<v8::Name> property,
-                                      const v8::PropertyCallbackInfo<v8::Value>& info) {
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekRecordGetter(
+    v8::Local<v8::Name> property,
+    const v8::PropertyCallbackInfo<v8::Value>& info) {
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
       static_cast<ZeekValWrap*>(receiver->GetAlignedPointerFromInternalField(0));
 
+#ifdef DEBUG
+  v8::Isolate* isolate = info.GetIsolate();
+  v8::String::Utf8Value property_utf8(isolate, property);
+  dprintf("%s", *property_utf8);
+#endif
+
   if (wrap->GetVal()->GetType()->Tag() != zeek::TYPE_RECORD)
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
 
   auto rval = wrap->GetVal()->AsRecordVal();
   const auto& rt = rval->GetType<zeek::RecordType>();
 
   auto offset = wrap->GetWrapper()->GetRecordFieldOffset(rt, property);
-  if (offset >= 0) {
-    zeek::ValPtr vp = rval->GetFieldOrDefault(offset);
-    info.GetReturnValue().Set(wrap->GetWrapper()->Wrap(vp, wrap->GetAttrMask()));
-  }
+  if (offset < 0)
+    return ZEEKJS_V8_INTERCEPTED_NO;
+
+  zeek::ValPtr vp = rval->GetFieldOrDefault(offset);
+  info.GetReturnValue().Set(wrap->GetWrapper()->Wrap(vp, wrap->GetAttrMask()));
+
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
 // Callback for for setting properties on a record.
-void ZeekValWrapper::ZeekRecordSetter(v8::Local<v8::Name> property,
-                                      v8::Local<v8::Value> v8_val,
-                                      const v8::PropertyCallbackInfo<v8::Value>& info) {
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekRecordSetter(
+    v8::Local<v8::Name> property,
+    v8::Local<v8::Value> v8_val,
+#if (NODE_MAJOR_VERSION <= 22)
+    const v8::PropertyCallbackInfo<v8::Value>& info) {
+#else
+    const v8::PropertyCallbackInfo<void>& info) {
+#endif
   v8::Isolate* isolate = info.GetIsolate();
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
@@ -1211,7 +1360,7 @@ void ZeekValWrapper::ZeekRecordSetter(v8::Local<v8::Name> property,
         ::v8_str(isolate, zeek::util::fmt("field %s does not exist in record type %s",
                                           *arg, rt->GetName().c_str())));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   zeek::TypePtr field_type = rt->GetFieldType(offset);
@@ -1230,11 +1379,12 @@ void ZeekValWrapper::ZeekRecordSetter(v8::Local<v8::Name> property,
     v8::Local<v8::Value> error =
         v8::Exception::TypeError(::v8_str(isolate, wrap_result.error.c_str()));
     isolate->ThrowException(error);
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
   }
 
   rval->Assign(offset, wrap_result.val);
   info.GetReturnValue().Set(v8_val);
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
 // Callback for enumerating the properties of a record.
@@ -1257,22 +1407,32 @@ void ZeekValWrapper::ZeekRecordEnumerator(
 }
 
 // Implement Query for Zeek records.
-void ZeekValWrapper::ZeekRecordQuery(
+ZEEKJS_V8_INTERCEPTED ZeekValWrapper::ZeekRecordQuery(
     v8::Local<v8::Name> property,
     const v8::PropertyCallbackInfo<v8::Integer>& info) {
   v8::Local<v8::Object> receiver = info.This();
   auto wrap =
       static_cast<ZeekValWrap*>(receiver->GetAlignedPointerFromInternalField(0));
 
+#ifdef DEBUG
+  v8::Isolate* isolate = info.GetIsolate();
+  v8::String::Utf8Value property_utf8(isolate, property);
+  dprintf("%s", *property_utf8);
+#endif
+
   const auto* val = wrap->GetVal();
   if (val->GetType()->Tag() != zeek::TYPE_RECORD)
-    return;
+    return ZEEKJS_V8_INTERCEPTED_NO;
 
   const auto& rt = val->GetType<zeek::RecordType>();
   auto offset = wrap->GetWrapper()->GetRecordFieldOffset(rt, property);
-  if (offset >= 0) {
-    info.GetReturnValue().Set(v8::PropertyAttribute::ReadOnly);
-  }
+  if (offset < 0)
+    return ZEEKJS_V8_INTERCEPTED_NO;
+
+  info.GetReturnValue().Set(v8::PropertyAttribute::ReadOnly |
+                            v8::PropertyAttribute::DontDelete);
+
+  return ZEEKJS_V8_INTERCEPTED_YES;
 }
 
 v8::Local<v8::String> ZeekValWrapper::v8_str_intern(const char* s) {
