@@ -54,7 +54,7 @@ static int bi_ffs(uint32_t value) {
     return add + bvals[value & 0xf];
 }
 
-#define first_n_bit_mask(n) (~(0xFFFFFFFFU >> n))
+static inline uint64_t first_n_bit_mask(int n) { return ~(0xFFFFFFFFU >> n); }
 
 ipaddr32_t AnonymizeIPAddr::Anonymize(ipaddr32_t addr) {
     std::map<ipaddr32_t, ipaddr32_t>::iterator p = mapping.find(addr);
@@ -259,6 +259,10 @@ AnonymizeIPAddr_A50::Node* AnonymizeIPAddr_A50::make_peer(ipaddr32_t a, Node* n)
     // swivel is first bit 'a' and 'old->input' differ.
     int swivel = bi_ffs(a ^ n->input);
 
+    // Shifting by more than 31 bits below results in undefined behavior.
+    // This shouldn't be possible, but check anyways.
+    ASSERT(swivel > 0);
+
     // bitvalue is the value of that bit of 'a'.
     int bitvalue = (a >> (32 - swivel)) & 1;
 
@@ -305,6 +309,10 @@ AnonymizeIPAddr_A50::Node* AnonymizeIPAddr_A50::find_node(ipaddr32_t a) {
             // differ.
             int swivel = bi_ffs(n->child[0]->input ^ n->child[1]->input);
 
+            // Shifting by more than 31 bits below results in undefined behavior.
+            // This shouldn't be possible, but check anyways.
+            ASSERT(swivel > 0);
+
             if ( bi_ffs(a ^ n->input) < swivel )
                 // Input differs earlier.
                 n = make_peer(a, n);
