@@ -38,7 +38,6 @@ using ztd::out_ptr::out_ptr;
 #include "zeek/Hash.h"
 #include "zeek/ID.h"
 #include "zeek/IntrusivePtr.h"
-#include "zeek/NetVar.h"
 #include "zeek/Reporter.h"
 #include "zeek/RunState.h"
 #include "zeek/Val.h"
@@ -190,7 +189,7 @@ void DNS_Request::MakeRequest(ares_channel channel, DNS_Mgr* mgr) {
         // back in the same request if use ares_getaddrinfo() so we can store them both
         // in the same mapping.
         ares_addrinfo_hints hints = {ARES_AI_CANONNAME, AF_UNSPEC, 0, 0};
-        ares_getaddrinfo(channel, host.c_str(), NULL, &hints, addrinfo_cb, req_data.release());
+        ares_getaddrinfo(channel, host.c_str(), nullptr, &hints, addrinfo_cb, req_data.release());
     }
     else {
         std::string query_host;
@@ -215,7 +214,7 @@ void DNS_Request::MakeRequest(ares_channel channel, DNS_Mgr* mgr) {
 
         // Store this so it can be destroyed when the request is destroyed.
         this->query_rec = std::move(dnsrec);
-        ares_send_dnsrec(channel, query_rec.get(), query_cb, req_data.release(), NULL);
+        ares_send_dnsrec(channel, query_rec.get(), query_cb, req_data.release(), nullptr);
     }
 }
 
@@ -303,7 +302,7 @@ static void addrinfo_cb(void* arg, int status, int timeouts, struct ares_addrinf
     else {
         std::vector<in_addr*> addrs;
         std::vector<in6_addr*> addrs6;
-        for ( ares_addrinfo_node* entry = result->nodes; entry != NULL; entry = entry->ai_next ) {
+        for ( ares_addrinfo_node* entry = result->nodes; entry != nullptr; entry = entry->ai_next ) {
             if ( entry->ai_family == AF_INET ) {
                 struct sockaddr_in* addr = reinterpret_cast<sockaddr_in*>(entry->ai_addr);
                 addrs.push_back(&addr->sin_addr);
@@ -316,7 +315,7 @@ static void addrinfo_cb(void* arg, int status, int timeouts, struct ares_addrinf
 
         if ( ! addrs.empty() ) {
             // Push a null on the end so the addr list has a final point during later parsing.
-            addrs.push_back(NULL);
+            addrs.push_back(nullptr);
 
             struct hostent he{};
             he.h_name = util::copy_string(result->name);
@@ -331,7 +330,7 @@ static void addrinfo_cb(void* arg, int status, int timeouts, struct ares_addrinf
 
         if ( ! addrs6.empty() ) {
             // Push a null on the end so the addr list has a final point during later parsing.
-            addrs6.push_back(NULL);
+            addrs6.push_back(nullptr);
 
             struct hostent he{};
             he.h_name = util::copy_string(result->name);
@@ -390,7 +389,7 @@ static void query_cb(void* arg, ares_status_t status, size_t timeouts, const are
 
             if ( type == ARES_REC_TYPE_PTR ) {
                 const char* txt = ares_dns_rr_get_str(rr, ARES_RR_PTR_DNAME);
-                if ( txt == NULL ) {
+                if ( txt == nullptr ) {
                     // According to the c-ares docs, this can happen but only in cases of "misuse". We
                     // still need to check for it though.
                     error = true;
@@ -412,7 +411,7 @@ static void query_cb(void* arg, ares_status_t status, size_t timeouts, const are
                 // TODO: We only process the first abin in the response. There might be more.
                 size_t abin_len;
                 const unsigned char* abin = ares_dns_rr_get_abin(rr, ARES_RR_TXT_DATA, 0, &abin_len);
-                if ( abin == NULL ) {
+                if ( abin == nullptr ) {
                     // According to the c-ares docs, this can happen but only in cases of "misuse". We
                     // still need to check for it though.
                     error = true;
@@ -873,9 +872,9 @@ void DNS_Mgr::Lookup(const std::string& name, int request_type, LookupCallback*
 
 void DNS_Mgr::Resolve() {
     int nfds = 0;
-    struct timeval *tvp, tv;
     struct pollfd pollfds[1024];
 
+    struct timeval tv;
     tv.tv_sec = DNS_TIMEOUT;
     tv.tv_usec = 0;
 
@@ -904,7 +903,7 @@ void DNS_Mgr::Resolve() {
         }
 
         // poll() timeout is in milliseconds.
-        tvp = ares_timeout(channel, &tv, &tv);
+        struct timeval* tvp = ares_timeout(channel, &tv, &tv);
         int timeout_ms = tvp->tv_sec * 1000 + tvp->tv_usec / 1000;
 
         int res = poll(pollfds, nfds, timeout_ms);
@@ -1307,9 +1306,9 @@ double DNS_Mgr::GetNextTimeout() {
         return -1;
 
     struct timeval tv;
-    struct timeval* tvp = ares_timeout(channel, NULL, &tv);
+    struct timeval* tvp = ares_timeout(channel, nullptr, &tv);
 
-    // If you pass NULL as the max time argument to ares_timeout, it will return null if there
+    // If you pass nullptr as the max time argument to ares_timeout, it will return null if there
     // isn't anything waiting to be processed.
     if ( ! tvp )
         return -1;
@@ -1415,6 +1414,8 @@ TableValPtr DNS_Mgr::empty_addr_set() {
     return make_intrusive<TableVal>(std::move(s));
 }
 
+DNS_Mgr::AsyncRequest::AsyncRequest(const IPAddr& addr) : addr(addr), type(T_PTR) {}
+
 //////////////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -1572,9 +1573,9 @@ TEST_CASE("dns_mgr default mode" * doctest::skip(true)) {
     CHECK_FALSE(host_result->EqualTo(TestDNS_Mgr::empty_addr_set()));
 
     auto addrs_from_request = get_result_addresses(host_result);
-    auto it = std::find(addrs_from_request.begin(), addrs_from_request.end(), ones4);
+    auto it = std::ranges::find(addrs_from_request, ones4);
     CHECK(it != addrs_from_request.end());
-    it = std::find(addrs_from_request.begin(), addrs_from_request.end(), ones6);
+    it = std::ranges::find(addrs_from_request, ones6);
     CHECK(it != addrs_from_request.end());
 
     auto addr_result = mgr.LookupAddr(ones4);
@@ -1612,7 +1613,7 @@ TEST_CASE("dns_mgr async host" * doctest::skip(true)) {
     if ( ! cb.timeout ) {
         REQUIRE_FALSE(cb.addr_results.empty());
         IPAddr ones("1.1.1.1");
-        auto it = std::find(cb.addr_results.begin(), cb.addr_results.end(), ones);
+        auto it = std::ranges::find(cb.addr_results, ones);
         CHECK(it != cb.addr_results.end());
     }
 
