@@ -2,14 +2,11 @@
 
 #include "zeek/Discard.h"
 
-#include "zeek/zeek-config.h"
-
 #include <algorithm>
 
 #include "zeek/Func.h"
 #include "zeek/IP.h"
 #include "zeek/Reporter.h" // for InterpreterException
-#include "zeek/RunState.h"
 #include "zeek/Val.h"
 #include "zeek/Var.h"
 #include "zeek/ZeekString.h"
@@ -25,6 +22,8 @@ Discarder::Discarder() {
     discarder_maxlen = static_cast<int>(id::find_val("discarder_maxlen")->AsCount());
 }
 
+Discarder::~Discarder() {}
+
 bool Discarder::IsActive() { return check_ip || check_tcp || check_udp || check_icmp; }
 
 bool Discarder::NextPacket(const std::shared_ptr<IP_Hdr>& ip, int len, int caplen) {
@@ -135,7 +134,7 @@ Val* Discarder::BuildData(const u_char* data, int hdrlen, int len, int caplen) {
     caplen -= hdrlen;
     data += hdrlen;
 
-    len = std::max(std::min(std::min(len, caplen), discarder_maxlen), 0);
+    len = std::max(std::min({len, caplen, discarder_maxlen}), 0);
 
     return new StringVal(new String(data, len, true));
 }
