@@ -45,7 +45,7 @@ using DeltaVector = std::vector<std::unique_ptr<ValDelta>>;
 // be readily compared against future instances.
 class ValTrace {
 public:
-    ValTrace(const ValPtr& v);
+    ValTrace(ValPtr v);
     ~ValTrace() = default;
 
     const ValPtr& GetVal() const { return v; }
@@ -292,7 +292,7 @@ public:
     // Adds to the trace an update for the given value.
     void AddDelta(ValPtr val, std::string rhs, bool needs_lhs, bool is_first_def) {
         auto& d = is_post ? post_deltas : deltas;
-        d.emplace_back(DeltaGen(val, rhs, needs_lhs, is_first_def));
+        d.emplace_back(val, rhs, needs_lhs, is_first_def);
     }
 
     // Initially we analyze events pre-execution.  When this flag
@@ -440,8 +440,12 @@ private:
 class EventTraceMgr {
 public:
     EventTraceMgr(const std::string& trace_file);
+
     ~EventTraceMgr();
 
+    // Generates the trace upon exit.
+    void Generate();
+
     // Called at the beginning of invoking an event's handlers.
     void StartEvent(const ScriptFunc* ev, const zeek::Args* args);
 
@@ -463,6 +467,6 @@ private:
 };
 
 // If non-nil then we're doing event tracing.
-extern std::unique_ptr<EventTraceMgr> etm;
+extern std::unique_ptr<EventTraceMgr> event_trace_mgr;
 
 } // namespace zeek::detail
