@@ -2,8 +2,6 @@
 
 #include "zeek/Stmt.h"
 
-#include "zeek/zeek-config.h"
-
 #include "zeek/CompHash.h"
 #include "zeek/Debug.h"
 #include "zeek/Desc.h"
@@ -13,7 +11,6 @@
 #include "zeek/File.h"
 #include "zeek/Frame.h"
 #include "zeek/IntrusivePtr.h"
-#include "zeek/NetVar.h"
 #include "zeek/Reporter.h"
 #include "zeek/Scope.h"
 #include "zeek/Traverse.h"
@@ -155,7 +152,7 @@ bool Stmt::SetLocationInfo(const Location* start, const Location* end) {
 
     // Update the Filemap of line number -> statement mapping for
     // breakpoints (Debug.h).
-    auto map_iter = g_dbgfilemaps.find(location->filename);
+    auto map_iter = g_dbgfilemaps.find(location->FileName());
     if ( map_iter == g_dbgfilemaps.end() )
         return false;
 
@@ -348,7 +345,7 @@ void do_print_stmt(const std::vector<ValPtr>& vals) {
         d.SetStyle(style);
 
         describe_vals(vals, &d, offset);
-        f->Write(d.Description(), d.Len());
+        f->Write(d.Description(), d.Size());
     }
     else {
         ODesc d(DESC_READABLE, f);
@@ -429,10 +426,6 @@ IfStmt::IfStmt(ExprPtr test, StmtPtr arg_s1, StmtPtr arg_s2)
     : ExprStmt(STMT_IF, std::move(test)), s1(std::move(arg_s1)), s2(std::move(arg_s2)) {
     if ( ! e->IsError() && ! IsBool(e->GetType()->Tag()) )
         e->Error("conditional in test must be boolean");
-
-    const Location* loc1 = s1->GetLocationInfo();
-    const Location* loc2 = s2->GetLocationInfo();
-    SetLocationInfo(loc1, loc2);
 }
 
 IfStmt::~IfStmt() = default;
@@ -645,7 +638,7 @@ void SwitchStmt::Init() {
 }
 
 SwitchStmt::SwitchStmt(ExprPtr index, case_list* arg_cases)
-    : ExprStmt(STMT_SWITCH, std::move(index)), cases(arg_cases), default_case_idx(-1) {
+    : ExprStmt(STMT_SWITCH, std::move(index)), cases(arg_cases) {
     Init();
 
     bool have_exprs = false;
@@ -679,21 +672,21 @@ SwitchStmt::SwitchStmt(ExprPtr index, case_list* arg_cases)
                             NegExpr* ne = (NegExpr*)(expr);
 
                             if ( ne->Op()->IsConst() )
-                                Unref(exprs.replace(j, new ConstExpr(ne->Eval(nullptr))));
+                                Unref(exprs.replace(j, new ConstExpr(eval_in_isolation(ne))));
                         } break;
 
                         case EXPR_POSITIVE: {
                             PosExpr* pe = (PosExpr*)(expr);
 
                             if ( pe->Op()->IsConst() )
-                                Unref(exprs.replace(j, new ConstExpr(pe->Eval(nullptr))));
+                                Unref(exprs.replace(j, new ConstExpr(eval_in_isolation(pe))));
                         } break;
 
                         case EXPR_NAME: {
                             NameExpr* ne = (NameExpr*)(expr);
 
                             if ( ne->Id()->IsConst() ) {
-                                auto v = ne->Eval(nullptr);
+                                auto v = eval_in_isolation(ne);
 
                                 if ( v )
                                     Unref(exprs.replace(j, new ConstExpr(std::move(v))));
@@ -905,8 +898,8 @@ ValPtr EventStmt::Exec(Frame* f, StmtFlowType& flow) {
     auto h = event_expr->Handler();
 
     if ( args && h ) {
-        if ( etm )
-            etm->ScriptEventQueued(h);
+        if ( event_trace_mgr )
+            event_trace_mgr->ScriptEventQueued(h);
 
         event_mgr.Enqueue(h, std::move(*args));
     }
@@ -1229,7 +1222,7 @@ ValPtr ForStmt::DoExec(Frame* f, Val* v, StmtFlowType& flow) {
 bool ForStmt::IsPure() const { return e->IsPure() && body->IsPure(); }
 
 void ForStmt::StmtDescribe(ODesc* d) const {
-    Stmt::StmtDescribe(d);
+    Stmt::StmtDescribe(d); // NOLINT(bugprone-parent-virtual-call)
 
     if ( d->IsReadable() )
         d->Add("(");
@@ -1401,7 +1394,7 @@ ValPtr ReturnStmt::Exec(Frame* f, StmtFlowType& flow) {
 }
 
 void ReturnStmt::StmtDescribe(ODesc* d) const {
-    Stmt::StmtDescribe(d);
+    Stmt::StmtDescribe(d); // NOLINT(bugprone-parent-virtual-call)
     if ( ! d->IsReadable() )
         d->Add(e != nullptr);
 
@@ -1491,7 +1484,7 @@ InitStmt::InitStmt(std::vector<IDPtr> arg_inits) : Stmt(STMT_INIT) {
     inits = std::move(arg_inits);
 
     if ( ! inits.empty() )
-        SetLocationInfo(inits[0]->GetLocationInfo());
+        SetLocationInfo(inits.front()->GetLocationInfo(), inits.back()->GetLocationInfo());
 }
 
 ValPtr InitStmt::Exec(Frame* f, StmtFlowType& flow) {
@@ -1610,7 +1603,7 @@ ValPtr AssertStmt::Exec(Frame* f, StmtFlowType& flow) {
 }
 
 void AssertStmt::StmtDescribe(ODesc* d) const {
-    Stmt::StmtDescribe(d);
+    Stmt::StmtDescribe(d); // NOLINT(bugprone-parent-virtual-call)
 
     // Quoting strings looks better when describing assert
     // statements. So turn it on explicitly.
@@ -1737,10 +1730,10 @@ WhenInfo::WhenInfo(ExprPtr arg_cond, FuncType::CaptureList* arg_cl, bool arg_is_
 }
 
 WhenInfo::WhenInfo(const WhenInfo* orig) {
-    if ( orig->cl ) {
-        cl = new FuncType::CaptureList;
+    cl = new FuncType::CaptureList;
+
+    if ( orig->cl )
         *cl = *orig->cl;
-    }
 
     cond = orig->OrigCond()->Duplicate();
 
