@@ -4,11 +4,8 @@
 
 #include "zeek/analyzer/protocol/irc/IRC.h"
 
-#include <iostream>
 #include <unordered_set>
 
-#include "zeek/Event.h"
-#include "zeek/NetVar.h"
 #include "zeek/analyzer/Manager.h"
 #include "zeek/analyzer/protocol/irc/events.bif.h"
 #include "zeek/analyzer/protocol/zip/ZIP.h"
@@ -81,6 +78,20 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
         return;
     }
 
+    // IRCv3 can pass arbitrary tags at the start of each line. Commonly this is @time,
+    // which is a timestamp for when the message was sent. They come as a semi-colon
+    // separated list, and are separated from the rest of the line by a space.
+    if ( myline.starts_with("@") ) {
+        std::size_t first_space = myline.find(' ');
+        // A set of tags doesn't necessarily need to be followed by a command. In this
+        // case just return.
+        if ( first_space == string::npos )
+            return;
+
+        // We don't do anything with tags right now. Just skip over them.
+        myline = myline.substr(first_space + 1);
+    }
+
     // Check for prefix.
     string prefix = "";
     if ( myline[0] == ':' ) { // find end of prefix and extract it
@@ -128,8 +139,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
             pos = myline.length();
 
         command = myline.substr(0, pos);
-        for ( size_t i = 0; i < command.size(); ++i )
-            command[i] = toupper(command[i]);
+        command = util::to_upper(command);
 
         // Adjust for the no-parameter case
         if ( pos == myline.length() )
@@ -229,8 +239,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                     // else ###
                 }
 
-                EnqueueConnEvent(irc_network_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Int(users),
-                                 val_mgr->Int(services), val_mgr->Int(servers));
+                EnqueueConnEvent(irc_network_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Count(users),
+                                 val_mgr->Count(services), val_mgr->Count(servers));
             } break;
 
             // List of users in a channel (names command).
@@ -283,9 +293,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                 int servers = 0;
 
                 for ( size_t i = 1; i < parts.size(); ++i ) {
-                    if ( parts[i] == "users," )
-                        users = atoi(parts[i - 1].c_str());
-                    else if ( parts[i] == "clients" )
+                    if ( parts[i] == "users," || parts[i] == "clients" )
                         users = atoi(parts[i - 1].c_str());
                     else if ( parts[i] == "services" )
                         services = atoi(parts[i - 1].c_str());
@@ -294,8 +302,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                     // else ###
                 }
 
-                EnqueueConnEvent(irc_server_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Int(users),
-                                 val_mgr->Int(services), val_mgr->Int(servers));
+                EnqueueConnEvent(irc_server_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Count(users),
+                                 val_mgr->Count(services), val_mgr->Count(servers));
             } break;
 
             // Count of channels.
@@ -309,7 +317,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                     if ( parts[i] == ":channels" )
                         channels = atoi(parts[i - 1].c_str());
 
-                EnqueueConnEvent(irc_channel_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Int(channels));
+                EnqueueConnEvent(irc_channel_info, ConnVal(), val_mgr->Bool(orig), val_mgr->Count(channels));
             } break;
 
             // RPL_GLOBALUSERS
@@ -362,8 +370,10 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                 parts.erase(parts.begin(), parts.begin() + 4);
 
                 string real_name = parts[0];
-                for ( size_t i = 1; i < parts.size(); ++i )
-                    real_name = real_name + " " + parts[i];
+                for ( size_t i = 1; i < parts.size(); ++i ) {
+                    real_name += " ";
+                    real_name += parts[i];
+                }
 
                 if ( real_name[0] == ':' )
                     real_name = real_name.substr(1);
@@ -473,7 +483,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
                                  make_intrusive<StringVal>(parts[3].c_str()),
                                  make_intrusive<StringVal>(parts[4].c_str()),
                                  make_intrusive<StringVal>(parts[5].c_str()),
-                                 make_intrusive<StringVal>(parts[6].c_str()), val_mgr->Int(atoi(parts[7].c_str())),
+                                 make_intrusive<StringVal>(parts[6].c_str()), val_mgr->Count(atoi(parts[7].c_str())),
                                  make_intrusive<StringVal>(parts[8].c_str()));
             } break;
 
@@ -537,7 +547,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
             message = message.substr(1); // DCC
 
         // Check for DCC messages.
-        if ( message.size() > 3 && message.substr(0, 3) == "DCC" ) {
+        if ( message.size() > 3 && message.starts_with("DCC") ) {
             if ( message[message.size() - 1] == 1 )
                 message = message.substr(0, message.size() - 1);
 
@@ -746,9 +756,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
 
         string empty_string = "";
 
-        for ( unsigned int i = 0; i < users.size(); ++i ) {
+        for ( auto nick : users ) {
             auto info = make_intrusive<RecordVal>(irc_join_info);
-            string nick = users[i];
             string mode = "none";
 
             if ( nick[0] == '@' ) {
@@ -812,8 +821,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
     }
 
     else if ( irc_quit_message && command == "QUIT" ) {
-        string message = params;
-        if ( message[0] == ':' )
+        string_view message{params};
+        if ( message.starts_with(":") )
             message = message.substr(1);
 
         string nickname = "";
@@ -824,16 +833,16 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
         }
 
         EnqueueConnEvent(irc_quit_message, ConnVal(), val_mgr->Bool(orig), make_intrusive<StringVal>(nickname.c_str()),
-                         make_intrusive<StringVal>(message.c_str()));
+                         make_intrusive<StringVal>(message));
     }
 
     else if ( irc_nick_message && command == "NICK" ) {
-        string nick = params;
+        string_view nick{params};
         if ( nick[0] == ':' )
             nick = nick.substr(1);
 
         EnqueueConnEvent(irc_nick_message, ConnVal(), val_mgr->Bool(orig), make_intrusive<StringVal>(prefix.c_str()),
-                         make_intrusive<StringVal>(nick.c_str()));
+                         make_intrusive<StringVal>(nick));
     }
 
     else if ( irc_who_message && command == "WHO" ) {
@@ -914,8 +923,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
     }
 
     else if ( irc_squit_message && command == "SQUIT" ) {
-        string server = params;
-        string message = "";
+        string server;
+        string message;
 
         unsigned int pos = params.find(' ');
         if ( pos < params.size() ) {
@@ -951,8 +960,6 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
         AddSupportAnalyzer(new analyzer::zip::ZIP_Analyzer(Conn(), true));
         AddSupportAnalyzer(new analyzer::zip::ZIP_Analyzer(Conn(), false));
     }
-
-    return;
 }
 
 void IRC_Analyzer::StartTLS() {
