@@ -2,13 +2,9 @@
 
 #include "zeek/analyzer/protocol/login/Login.h"
 
-#include "zeek/zeek-config.h"
-
 #include <cctype>
 #include <cstdlib>
 
-#include "zeek/Event.h"
-#include "zeek/NetVar.h"
 #include "zeek/RE.h"
 #include "zeek/Reporter.h"
 #include "zeek/Var.h"
@@ -28,7 +24,7 @@ static RE_Matcher* re_login_timeouts;
 static RE_Matcher* init_RE(ListVal* l);
 
 Login_Analyzer::Login_Analyzer(const char* name, Connection* conn)
-    : analyzer::tcp::TCP_ApplicationAnalyzer(name, conn), user_text() {
+    : analyzer::tcp::TCP_ApplicationAnalyzer(name, conn) {
     state = LOGIN_STATE_AUTHENTICATE;
     num_user_lines_seen = lines_scanned = 0;
     // Set last_failure_num_user_lines so we will always generate
@@ -80,8 +76,8 @@ void Login_Analyzer::DeliverStream(int length, const u_char* line, bool orig) {
     char* str = new char[length + 1];
 
     // Eliminate NUL characters.
-    int i, j;
-    for ( i = 0, j = 0; i < length; ++i )
+    int j = 0;
+    for ( int i = 0; i < length; ++i )
         if ( line[i] != '\0' )
             str[j++] = line[i];
         else {
@@ -137,10 +133,11 @@ void Login_Analyzer::NewLine(bool orig, char* line) {
     }
 }
 
+constexpr char VMS_REPEAT_SEQ[] = "\x1b[A";
+
 void Login_Analyzer::AuthenticationDialog(bool orig, char* line) {
     if ( orig ) {
         if ( is_VMS ) {
-#define VMS_REPEAT_SEQ "\x1b[A"
             char* repeat_prev_line = strstr(line, VMS_REPEAT_SEQ);
             if ( repeat_prev_line ) {
                 if ( repeat_prev_line[strlen(VMS_REPEAT_SEQ)] ) {
@@ -183,7 +180,7 @@ void Login_Analyzer::AuthenticationDialog(bool orig, char* line) {
     const char* prompt = IsLoginPrompt(line);
     bool is_timeout = IsTimeout(line);
     if ( prompt && ! IsSuccessMsg(line) && ! is_timeout ) {
-        is_VMS = strstr(line, "Username:") != 0;
+        is_VMS = strstr(line, "Username:") != nullptr;
 
         // If we see multiple login prompts, presume that
         // each is consuming one line of typeahead.
