@@ -24,8 +24,6 @@ static const char* pop3_cmd_word[] = {
 #include "POP3_cmd.def"
 };
 
-#define POP3_CMD_WORD(code) (((code) >= 0) ? pop3_cmd_word[code] : "(UNKNOWN)")
-
 POP3_Analyzer::POP3_Analyzer(Connection* conn) : analyzer::tcp::TCP_ApplicationAnalyzer("POP3", conn) {
     masterState = detail::POP3_START;
     subState = detail::POP3_WOK;
@@ -786,8 +784,7 @@ int POP3_Analyzer::ParseCmd(std::string cmd) {
         if ( c == '+' || c == '-' )
             cmd = cmd.substr(1);
 
-        for ( size_t i = 0; i < cmd.size(); ++i )
-            cmd[i] = toupper(cmd[i]);
+        cmd = util::to_upper(cmd);
 
         if ( ! cmd.compare(pop3_cmd_word[code]) )
             return code;
