@@ -2,19 +2,14 @@
 
 #include "zeek/analyzer/protocol/tcp/TCP.h"
 
-#include <vector>
-
 #include "zeek/DebugLogger.h"
 #include "zeek/Event.h"
 #include "zeek/File.h"
 #include "zeek/IP.h"
-#include "zeek/NetVar.h"
 #include "zeek/Reporter.h"
 #include "zeek/RunState.h"
-#include "zeek/analyzer/protocol/pia/PIA.h"
 #include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 #include "zeek/analyzer/protocol/tcp/events.bif.h"
-#include "zeek/analyzer/protocol/tcp/types.bif.h"
 #include "zeek/session/Manager.h"
 
 namespace zeek::analyzer::tcp {
@@ -200,8 +195,7 @@ RecordVal* TCPStats_Endpoint::BuildStats() {
     return stats;
 }
 
-TCPStats_Analyzer::TCPStats_Analyzer(Connection* c)
-    : TCP_ApplicationAnalyzer("TCPSTATS", c), orig_stats(), resp_stats() {}
+TCPStats_Analyzer::TCPStats_Analyzer(Connection* c) : TCP_ApplicationAnalyzer("TCPSTATS", c) {}
 
 TCPStats_Analyzer::~TCPStats_Analyzer() {
     delete orig_stats;
