@@ -8,26 +8,19 @@
 #include "zeek/Event.h"
 #include "zeek/UID.h"
 #include "zeek/analyzer/Manager.h"
-#include "zeek/digest.h"
 #include "zeek/file_analysis/Analyzer.h"
 #include "zeek/file_analysis/File.h"
 #include "zeek/file_analysis/file_analysis.bif.h"
-#include "zeek/plugin/Manager.h"
 
 using namespace std;
 
 namespace zeek::file_analysis {
 
-Manager::Manager()
-    : plugin::ComponentManager<file_analysis::Component>("Files", "Tag", "AllAnalyzers"),
-      current_file_id(),
-      magic_state(),
-      cumulative_files(0),
-      max_files(0) {}
+Manager::Manager() : plugin::ComponentManager<file_analysis::Component>("Files", "Tag", "AllAnalyzers") {}
 
 Manager::~Manager() {
-    for ( MIMEMap::iterator i = mime_types.begin(); i != mime_types.end(); i++ )
-        delete i->second;
+    for ( const auto& [_, tag] : mime_types )
+        delete tag;
 
     // Have to assume that too much of Zeek has been shutdown by this point
     // to do anything more than reclaim memory.
@@ -475,12 +468,12 @@ VectorValPtr GenMIMEMatchesVal(const zeek::detail::RuleMatcher::MIME_Matches& m)
     static auto mime_match = id::find_type<RecordType>("mime_match");
     auto rval = make_intrusive<VectorVal>(mime_matches);
 
-    for ( zeek::detail::RuleMatcher::MIME_Matches::const_iterator it = m.begin(); it != m.end(); ++it ) {
+    for ( const auto& [index, match] : m ) {
         auto element = make_intrusive<RecordVal>(mime_match);
 
-        for ( set<string>::const_iterator it2 = it->second.begin(); it2 != it->second.end(); ++it2 ) {
-            element->Assign(0, it->first);
-            element->Assign(1, *it2);
+        for ( const string& match_str : match ) {
+            element->Assign(0, index);
+            element->Assign(1, match_str);
         }
 
         rval->Assign(rval->Size(), std::move(element));
