@@ -7,12 +7,11 @@
 
 #include "zeek/CompHash.h"
 #include "zeek/Desc.h"
+#include "zeek/Dict.h"
 #include "zeek/Event.h"
 #include "zeek/EventHandler.h"
 #include "zeek/Expr.h"
 #include "zeek/Func.h"
-#include "zeek/NetVar.h"
-#include "zeek/RunState.h"
 #include "zeek/file_analysis/Manager.h"
 #include "zeek/input/ReaderBackend.h"
 #include "zeek/input/ReaderFrontend.h"
@@ -52,16 +51,16 @@ static void input_hash_delete_func(void* val) {
 class Manager::Stream {
 public:
     string name;
-    bool removed;
+    bool removed = false;
 
     StreamType stream_type; // to distinguish between event and table streams
 
-    EnumVal* type;
-    ReaderFrontend* reader;
-    TableVal* config;
+    EnumVal* type = nullptr;
+    ReaderFrontend* reader = nullptr;
+    TableVal* config = nullptr;
     EventHandlerPtr error_event;
 
-    RecordVal* description;
+    RecordVal* description = nullptr;
 
     virtual ~Stream();
 
@@ -69,8 +68,7 @@ protected:
     Stream(StreamType t);
 };
 
-Manager::Stream::Stream(StreamType t)
-    : name(), removed(), stream_type(t), type(), reader(), config(), error_event(), description() {}
+Manager::Stream::Stream(StreamType t) : stream_type(t) {}
 
 Manager::Stream::~Stream() {
     Unref(type);
@@ -81,18 +79,18 @@ Manager::Stream::~Stream() {
 
 class Manager::TableStream final : public Manager::Stream {
 public:
-    unsigned int num_idx_fields;
-    unsigned int num_val_fields;
-    bool want_record;
+    unsigned int num_idx_fields = 0;
+    unsigned int num_val_fields = 0;
+    bool want_record = false;
 
-    TableVal* tab;
-    RecordType* rtype;
-    RecordType* itype;
+    TableVal* tab = nullptr;
+    RecordType* rtype = nullptr;
+    RecordType* itype = nullptr;
 
-    PDict<InputHash>* currDict;
-    PDict<InputHash>* lastDict;
+    PDict<InputHash>* currDict = nullptr;
+    PDict<InputHash>* lastDict = nullptr;
 
-    Func* pred;
+    Func* pred = nullptr;
 
     EventHandlerPtr event;
 
@@ -104,10 +102,10 @@ class Manager::EventStream final : public Manager::Stream {
 public:
     EventHandlerPtr event;
 
-    RecordType* fields;
-    unsigned int num_fields;
+    RecordType* fields = nullptr;
+    unsigned int num_fields = 0;
 
-    bool want_record;
+    bool want_record = false;
     EventStream();
     ~EventStream() override;
 };
@@ -120,21 +118,9 @@ public:
     ~AnalysisStream() override = default;
 };
 
-Manager::TableStream::TableStream()
-    : Manager::Stream::Stream(TABLE_STREAM),
-      num_idx_fields(),
-      num_val_fields(),
-      want_record(),
-      tab(),
-      rtype(),
-      itype(),
-      currDict(),
-      lastDict(),
-      pred(),
-      event() {}
+Manager::TableStream::TableStream() : Manager::Stream::Stream(TABLE_STREAM) {}
 
-Manager::EventStream::EventStream()
-    : Manager::Stream::Stream(EVENT_STREAM), event(), fields(), num_fields(), want_record() {}
+Manager::EventStream::EventStream() : Manager::Stream::Stream(EVENT_STREAM) {}
 
 Manager::EventStream::~EventStream() {
     if ( fields )
@@ -170,9 +156,9 @@ Manager::Manager() : plugin::ComponentManager<input::Component>("Input", "Reader
 }
 
 Manager::~Manager() {
-    for ( map<ReaderFrontend*, Stream*>::iterator s = readers.begin(); s != readers.end(); ++s ) {
-        delete s->second;
-        delete s->first;
+    for ( auto& [frontend, stream] : readers ) {
+        delete stream;
+        delete frontend;
     }
 }
 
@@ -895,13 +881,14 @@ bool Manager::UnrollRecordType(vector<Field*>* fields, const RecordType* rec, co
         if ( rec->GetFieldType(i)->Tag() == TYPE_RECORD ) {
             string prep = nameprepend + rec->FieldName(i) + ".";
 
-            if ( rec->FieldDecl(i)->GetAttr(zeek::detail::ATTR_OPTIONAL) ) {
+            const auto* rt = rec->GetFieldType(i)->AsRecordType();
+            if ( rt->NumFields() > 0 && rec->FieldDecl(i)->GetAttr(zeek::detail::ATTR_OPTIONAL) ) {
                 reporter->Info("The input framework does not support optional record fields: \"%s\"",
                                rec->FieldName(i));
                 return false;
             }
 
-            if ( ! UnrollRecordType(fields, rec->GetFieldType(i)->AsRecordType(), prep, allow_file_func) ) {
+            if ( ! UnrollRecordType(fields, rt, prep, allow_file_func) ) {
                 return false;
             }
         }
@@ -923,7 +910,7 @@ bool Manager::UnrollRecordType(vector<Field*>* fields, const RecordType* rec, co
             else if ( ty == TYPE_PORT && rec->FieldDecl(i)->GetAttr(zeek::detail::ATTR_TYPE_COLUMN) ) {
                 // we have an annotation for the second column
 
-                c = rec->FieldDecl(i)->GetAttr(zeek::detail::ATTR_TYPE_COLUMN)->GetExpr()->Eval(nullptr);
+                c = eval_in_isolation(rec->FieldDecl(i)->GetAttr(zeek::detail::ATTR_TYPE_COLUMN)->GetExpr());
 
                 assert(c);
                 assert(c->GetType()->Tag() == TYPE_STRING);
@@ -1440,11 +1427,11 @@ int Manager::SendEventStreamEvent(Stream* i, EnumVal* type, const Value* const*
 
     if ( convert_error ) {
         // we have an error somewhere in our out_vals. Just delete all of them.
-        for ( list<Val*>::const_iterator it = out_vals.begin(), end = out_vals.end(); it != end; ++it )
-            Unref(*it);
+        for ( auto* val : out_vals )
+            Unref(val);
     }
     else
-        SendEvent(stream->event, out_vals);
+        SendEvent(stream->event, std::move(out_vals));
 
     return stream->num_fields;
 }
@@ -1713,8 +1700,8 @@ void Manager::SendEvent(EventHandlerPtr ev, list<Val*> events) const {
     DBG_LOG(DBG_INPUT, "SendEvent with %" PRIuPTR " vals (list)", events.size());
 #endif
 
-    for ( list<Val*>::iterator i = events.begin(); i != events.end(); i++ )
-        vl.emplace_back(AdoptRef{}, *i);
+    for ( auto* val : events )
+        vl.emplace_back(AdoptRef{}, val);
 
     if ( ev )
         event_mgr.Enqueue(ev, std::move(vl), util::detail::SOURCE_LOCAL);
@@ -2168,9 +2155,9 @@ Val* Manager::ValueToVal(const Stream* i, const Value* val, Type* request_type,
 }
 
 Manager::Stream* Manager::FindStream(const string& name) const {
-    for ( auto s = readers.begin(); s != readers.end(); ++s ) {
-        if ( (*s).second->name == name )
-            return (*s).second;
+    for ( const auto& [_, stream] : readers ) {
+        if ( stream->name == name )
+            return stream;
     }
 
     return nullptr;
@@ -2187,12 +2174,12 @@ Manager::Stream* Manager::FindStream(ReaderFrontend* reader) const {
 // Function is called on Zeek shutdown.
 // Signal all frontends that they will cease operation.
 void Manager::Terminate() {
-    for ( map<ReaderFrontend*, Stream*>::iterator i = readers.begin(); i != readers.end(); ++i ) {
-        if ( i->second->removed )
+    for ( const auto& [_, stream] : readers ) {
+        if ( stream->removed )
             continue;
 
-        i->second->removed = true;
-        i->second->reader->Stop();
+        stream->removed = true;
+        stream->reader->Stop();
     }
 }
 
