@@ -2,15 +2,13 @@
 
 #include "zeek/iosource/pcap/Source.h"
 
-#include "zeek/zeek-config.h"
-
 #include "zeek/3rdparty/doctest.h"
 
 #ifdef HAVE_PCAP_INT_H
 #include <pcap-int.h>
 #endif
 
-#include <stdio.h>
+#include <cstdio>
 
 #include "zeek/Event.h"
 #include "zeek/iosource/BPF_Program.h"
