@@ -8,12 +8,12 @@
 #include <utility>
 
 #include "zeek/Desc.h"
+#include "zeek/Dict.h"
 #include "zeek/Event.h"
 #include "zeek/EventHandler.h"
 #include "zeek/File.h"
 #include "zeek/Func.h"
 #include "zeek/IntrusivePtr.h"
-#include "zeek/NetVar.h"
 #include "zeek/OpaqueVal.h"
 #include "zeek/RunState.h"
 #include "zeek/Timer.h"
@@ -22,6 +22,7 @@
 #include "zeek/logging/WriterBackend.h"
 #include "zeek/logging/WriterFrontend.h"
 #include "zeek/logging/logging.bif.h"
+#include "zeek/module_util.h"
 #include "zeek/plugin/Manager.h"
 #include "zeek/plugin/Plugin.h"
 #include "zeek/telemetry/Manager.h"
@@ -63,7 +64,7 @@ using DelayInfoPtr = std::shared_ptr<DelayInfo>;
 class LogDelayTokenVal : public OpaqueVal {
 public:
     explicit LogDelayTokenVal(DelayTokenType token) : OpaqueVal(zeek::detail::log_delay_token_type), token(token) {}
-    virtual ~LogDelayTokenVal() = default;
+    ~LogDelayTokenVal() override {};
 
     ValPtr DoClone(CloneState* state) override;
 
@@ -107,8 +108,8 @@ class DelayInfo {
 public:
     static const DelayInfoPtr nil;
 
-    explicit DelayInfo(const WriteContext& ctx, const zeek::ValPtr token_val, double expire_time)
-        : ctx(ctx), token_val(token_val), expire_time(expire_time) {}
+    explicit DelayInfo(WriteContext ctx, const zeek::ValPtr token_val, double expire_time)
+        : ctx(std::move(ctx)), token_val(token_val), expire_time(expire_time) {}
 
     // No copy or assignment of DelayInfo itself, should
     // always be managed through a shared pointer.
@@ -342,7 +343,9 @@ Manager::Filter::~Filter() {
     for ( int i = 0; i < num_fields; ++i )
         delete fields[i];
 
-    free(fields);
+    // Static cast this to void* to avoid a clang-tidy warning about converting from the
+    // double-pointer to void*
+    free(static_cast<void*>(fields));
 
     Unref(path_val);
     Unref(config);
@@ -351,9 +354,7 @@ Manager::Filter::~Filter() {
 Manager::Stream::~Stream() {
     Unref(columns);
 
-    for ( WriterMap::iterator i = writers.begin(); i != writers.end(); i++ ) {
-        WriterInfo* winfo = i->second;
-
+    for ( auto& [_, winfo] : writers ) {
         if ( winfo->rotation_timer )
             zeek::detail::timer_mgr->Cancel(winfo->rotation_timer);
 
@@ -363,8 +364,8 @@ Manager::Stream::~Stream() {
         delete winfo;
     }
 
-    for ( list<Filter*>::iterator f = filters.begin(); f != filters.end(); ++f )
-        delete *f;
+    for ( Filter* f : filters )
+        delete f;
 
     if ( delay_timer )
         zeek::detail::timer_mgr->Cancel(delay_timer);
@@ -495,8 +496,8 @@ Manager::Manager()
 }
 
 Manager::~Manager() {
-    for ( vector<Stream*>::iterator s = streams.begin(); s != streams.end(); ++s )
-        delete *s;
+    for ( Stream* s : streams )
+        delete s;
 }
 
 void Manager::InitPostScript() {
@@ -529,13 +530,11 @@ Manager::Stream* Manager::FindStream(EnumVal* id) {
 }
 
 Manager::WriterInfo* Manager::FindWriter(WriterFrontend* writer) {
-    for ( vector<Stream*>::iterator s = streams.begin(); s != streams.end(); ++s ) {
-        if ( ! *s )
+    for ( Stream* s : streams ) {
+        if ( ! s )
             continue;
 
-        for ( Stream::WriterMap::iterator i = (*s)->writers.begin(); i != (*s)->writers.end(); i++ ) {
-            WriterInfo* winfo = i->second;
-
+        for ( const auto& [_, winfo] : s->writers ) {
             if ( winfo->writer == writer )
                 return winfo;
         }
@@ -568,16 +567,16 @@ bool Manager::CheckFilterWriterConflict(const WriterInfo* winfo, const Filter* f
 void Manager::RemoveDisabledWriters(Stream* stream) {
     list<Stream::WriterPathPair> disabled;
 
-    for ( Stream::WriterMap::iterator j = stream->writers.begin(); j != stream->writers.end(); j++ ) {
-        if ( j->second->writer->Disabled() ) {
-            j->second->writer->Stop();
-            delete j->second;
-            disabled.push_back(j->first);
+    for ( const auto& [index, winfo] : stream->writers ) {
+        if ( winfo->writer->Disabled() ) {
+            winfo->writer->Stop();
+            delete winfo;
+            disabled.push_back(index);
         }
     }
 
-    for ( list<Stream::WriterPathPair>::iterator j = disabled.begin(); j != disabled.end(); j++ )
-        stream->writers.erase(*j);
+    for ( const auto& index : disabled )
+        stream->writers.erase(index);
 }
 
 bool Manager::CreateStream(EnumVal* id, RecordVal* sval) {
@@ -686,9 +685,7 @@ bool Manager::RemoveStream(unsigned int idx) {
     if ( ! stream )
         return false;
 
-    for ( Stream::WriterMap::iterator i = stream->writers.begin(); i != stream->writers.end(); i++ ) {
-        WriterInfo* winfo = i->second;
-
+    for ( const auto& [_, winfo] : stream->writers ) {
         DBG_LOG(DBG_LOGGING, "Removed writer '%s' from stream '%s'", winfo->writer->Name(), stream->name.c_str());
 
         winfo->writer->Stop();
@@ -773,7 +770,7 @@ bool Manager::TraverseRecord(Stream* stream, Filter* filter, RecordType* rt, Tab
 
         // Add the ext prefix if this is an ext field.
         if ( j < num_ext_fields )
-            new_path = filter->ext_prefix + new_path;
+            new_path = string{filter->ext_prefix}.append(new_path);
 
         if ( t->InternalType() == TYPE_INTERNAL_OTHER ) {
             if ( t->Tag() == TYPE_RECORD ) {
@@ -784,19 +781,8 @@ bool Manager::TraverseRecord(Stream* stream, Filter* filter, RecordType* rt, Tab
                 continue;
             }
 
-            else if ( t->Tag() == TYPE_TABLE && t->AsTableType()->IsSet() ) {
-                // That's ok, we handle it below.
-            }
-
-            else if ( t->Tag() == TYPE_VECTOR ) {
-                // That's ok, we handle it below.
-            }
-
-            else if ( t->Tag() == TYPE_FILE ) {
-                // That's ok, we handle it below.
-            }
-
-            else if ( t->Tag() == TYPE_FUNC ) {
+            else if ( (t->Tag() == TYPE_TABLE && t->AsTableType()->IsSet()) || t->Tag() == TYPE_VECTOR ||
+                      t->Tag() == TYPE_FILE || t->Tag() == TYPE_FUNC ) {
                 // That's ok, we handle it below.
             }
 
@@ -827,9 +813,11 @@ bool Manager::TraverseRecord(Stream* stream, Filter* filter, RecordType* rt, Tab
         }
 
         // Alright, we want this field.
-        filter->indices.push_back(new_indices);
+        filter->indices.push_back(std::move(new_indices));
 
-        void* tmp = realloc(filter->fields, sizeof(threading::Field*) * (filter->num_fields + 1));
+        // Static cast this to void* to avoid a clang-tidy warning about converting from the
+        // double-pointer to void*
+        void* tmp = realloc(static_cast<void*>(filter->fields), sizeof(threading::Field*) * (filter->num_fields + 1));
 
         if ( ! tmp ) {
             reporter->Error("out of memory in add_filter");
@@ -1593,9 +1581,9 @@ detail::LogRecord Manager::RecordToLogRecord(const Stream* stream, Filter* filte
         // potentially be nested inside other records.
         list<int>& indices = filter->indices[i];
 
-        for ( list<int>::iterator j = indices.begin(); j != indices.end(); ++j ) {
+        for ( int index : indices ) {
             auto vr = val->AsRecord();
-            val = vr->RawOptField(*j);
+            val = vr->RawOptField(index);
 
             if ( ! val ) {
                 // Value, or any of its parents, is not set.
@@ -1603,7 +1591,7 @@ detail::LogRecord Manager::RecordToLogRecord(const Stream* stream, Filter* filte
                 break;
             }
 
-            vt = cast_intrusive<RecordType>(vr->GetType())->GetFieldType(*j).get();
+            vt = cast_intrusive<RecordType>(vr->GetType())->GetFieldType(index).get();
         }
 
         if ( val )
@@ -1904,21 +1892,19 @@ bool Manager::WriteFromRemote(EnumVal* id, EnumVal* writer, const string& path,
 void Manager::SendAllWritersTo(const broker::endpoint_info& ei) {
     auto et = id::find_type("Log::Writer")->AsEnumType();
 
-    for ( vector<Stream*>::iterator s = streams.begin(); s != streams.end(); ++s ) {
-        Stream* stream = (*s);
-
+    for ( Stream* stream : streams ) {
         if ( ! (stream && stream->enable_remote) )
             continue;
 
-        for ( Stream::WriterMap::iterator i = stream->writers.begin(); i != stream->writers.end(); i++ ) {
-            WriterFrontend* writer = i->second->writer;
-            const auto& writer_val = et->GetEnumVal(i->first.first);
+        for ( const auto& [index, winfo] : stream->writers ) {
+            WriterFrontend* writer = winfo->writer;
+            const auto& writer_val = et->GetEnumVal(index.first);
 
             std::vector<const threading::Field*> fields(writer->GetFields().size());
             for ( size_t i = 0; i < writer->GetFields().size(); i++ )
                 fields[i] = &writer->GetFields()[i];
 
-            broker_mgr->PublishLogCreate((*s)->id, writer_val.get(), *i->second->info, fields.size(), fields.data(),
+            broker_mgr->PublishLogCreate(stream->id, writer_val.get(), *(winfo->info), fields.size(), fields.data(),
                                          ei);
         }
     }
@@ -1929,8 +1915,8 @@ bool Manager::SetBuf(EnumVal* id, bool enabled) {
     if ( ! stream )
         return false;
 
-    for ( Stream::WriterMap::iterator i = stream->writers.begin(); i != stream->writers.end(); i++ )
-        i->second->writer->SetBuf(enabled);
+    for ( const auto& [_, winfo] : stream->writers )
+        winfo->writer->SetBuf(enabled);
 
     RemoveDisabledWriters(stream);
 
@@ -1945,8 +1931,8 @@ bool Manager::Flush(EnumVal* id) {
     if ( ! stream->enabled )
         return true;
 
-    for ( Stream::WriterMap::iterator i = stream->writers.begin(); i != stream->writers.end(); i++ )
-        i->second->writer->Flush(run_state::network_time);
+    for ( const auto& [_, winfo] : stream->writers )
+        winfo->writer->Flush(run_state::network_time);
 
     RemoveDisabledWriters(stream);
 
@@ -1954,12 +1940,12 @@ bool Manager::Flush(EnumVal* id) {
 }
 
 void Manager::Terminate() {
-    for ( vector<Stream*>::iterator s = streams.begin(); s != streams.end(); ++s ) {
-        if ( ! *s )
+    for ( Stream* s : streams ) {
+        if ( ! s )
             continue;
 
-        for ( Stream::WriterMap::iterator i = (*s)->writers.begin(); i != (*s)->writers.end(); i++ )
-            i->second->writer->Stop();
+        for ( const auto& [_, winfo] : s->writers )
+            winfo->writer->Stop();
     }
 }
 
