@@ -10,6 +10,7 @@
 #include <cerrno>
 #include <cstdio>
 #include <ctime>
+#include <filesystem>
 #include <memory>
 #include <optional>
 #include <string>
@@ -20,6 +21,8 @@
 #include "zeek/logging/Manager.h"
 #include "zeek/logging/writers/ascii/ascii.bif.h"
 #include "zeek/threading/SerialTypes.h"
+#include "zeek/threading/formatters/Ascii.h"
+#include "zeek/threading/formatters/JSON.h"
 #include "zeek/util.h"
 
 #include "zeek/3rdparty/doctest.h"
@@ -86,7 +89,7 @@ struct LeftoverLog {
      * Return the "path" (logging framework parlance) of the log without the
      * directory or file extension. E.g. the "path" of "logs/conn.log" is just "conn".
      */
-    std::string Path() const { return zeek::filesystem::path(filename).stem().string(); }
+    std::string Path() const { return std::filesystem::path(filename).stem().string(); }
 
     /**
      * Deletes the shadow file and returns whether it succeeded.
@@ -100,7 +103,7 @@ struct LeftoverLog {
  * prefix_basename_with("logs/conn.log", ".shadow") -> logs/.shadow.conn.log"
  */
 static std::string prefix_basename_with(const std::string& path, const std::string& prefix) {
-    auto fspath = zeek::filesystem::path(path);
+    auto fspath = std::filesystem::path(path);
     auto new_filename = prefix + fspath.filename().string();
     return (fspath.parent_path() / new_filename).string();
 }
@@ -202,7 +205,7 @@ static std::optional<LeftoverLog> parse_shadow_log(const std::string& fname) {
     return rval;
 }
 
-Ascii::Ascii(WriterFrontend* frontend) : WriterBackend(frontend) {
+Ascii::Ascii(WriterFrontend* frontend) : WriterBackend(frontend, /*send_heartbeats=*/false) {
     fd = 0;
     ascii_done = false;
     output_to_stdout = false;
@@ -237,10 +240,7 @@ void Ascii::InitConfigOptions() {
 
     meta_prefix.assign((const char*)BifConst::LogAscii::meta_prefix->Bytes(), BifConst::LogAscii::meta_prefix->Len());
 
-    ODesc tsfmt;
-    BifConst::LogAscii::json_timestamps->Describe(&tsfmt);
-    json_timestamps.assign((const char*)tsfmt.Bytes(), tsfmt.Len());
-
+    json_timestamps = zeek::obj_desc_short(BifConst::LogAscii::json_timestamps);
     json_include_unset_fields = BifConst::LogAscii::json_include_unset_fields;
 
     gzip_file_extension.assign((const char*)BifConst::LogAscii::gzip_file_extension->Bytes(),
@@ -253,11 +253,11 @@ bool Ascii::InitFilterOptions() {
     const WriterInfo& info = Info();
 
     // Set per-filter configuration options.
-    for ( WriterInfo::config_map::const_iterator i = info.config.begin(); i != info.config.end(); ++i ) {
-        if ( strcmp(i->first, "tsv") == 0 ) {
-            if ( strcmp(i->second, "T") == 0 )
+    for ( const auto& [key, value] : info.config ) {
+        if ( strcmp(key, "tsv") == 0 ) {
+            if ( strcmp(value, "T") == 0 )
                 tsv = true;
-            else if ( strcmp(i->second, "F") == 0 )
+            else if ( strcmp(value, "F") == 0 )
                 tsv = false;
             else {
                 Error("invalid value for 'tsv', must be a string and either \"T\" or \"F\"");
@@ -265,18 +265,18 @@ bool Ascii::InitFilterOptions() {
             }
         }
 
-        else if ( strcmp(i->first, "gzip_level") == 0 ) {
-            gzip_level = atoi(i->second);
+        else if ( strcmp(key, "gzip_level") == 0 ) {
+            gzip_level = atoi(value);
 
             if ( gzip_level < 0 || gzip_level > 9 ) {
                 Error("invalid value for 'gzip_level', must be a number between 0 and 9.");
                 return false;
             }
         }
-        else if ( strcmp(i->first, "use_json") == 0 ) {
-            if ( strcmp(i->second, "T") == 0 )
+        else if ( strcmp(key, "use_json") == 0 ) {
+            if ( strcmp(value, "T") == 0 )
                 use_json = true;
-            else if ( strcmp(i->second, "F") == 0 )
+            else if ( strcmp(value, "F") == 0 )
                 use_json = false;
             else {
                 Error("invalid value for 'use_json', must be a string and either \"T\" or \"F\"");
@@ -284,10 +284,10 @@ bool Ascii::InitFilterOptions() {
             }
         }
 
-        else if ( strcmp(i->first, "enable_utf_8") == 0 ) {
-            if ( strcmp(i->second, "T") == 0 )
+        else if ( strcmp(key, "enable_utf_8") == 0 ) {
+            if ( strcmp(value, "T") == 0 )
                 enable_utf_8 = true;
-            else if ( strcmp(i->second, "F") == 0 )
+            else if ( strcmp(value, "F") == 0 )
                 enable_utf_8 = false;
             else {
                 Error("invalid value for 'enable_utf_8', must be a string and either \"T\" or \"F\"");
@@ -295,10 +295,10 @@ bool Ascii::InitFilterOptions() {
             }
         }
 
-        else if ( strcmp(i->first, "output_to_stdout") == 0 ) {
-            if ( strcmp(i->second, "T") == 0 )
+        else if ( strcmp(key, "output_to_stdout") == 0 ) {
+            if ( strcmp(value, "T") == 0 )
                 output_to_stdout = true;
-            else if ( strcmp(i->second, "F") == 0 )
+            else if ( strcmp(value, "F") == 0 )
                 output_to_stdout = false;
             else {
                 Error(
@@ -308,28 +308,28 @@ bool Ascii::InitFilterOptions() {
             }
         }
 
-        else if ( strcmp(i->first, "separator") == 0 )
-            separator.assign(i->second);
+        else if ( strcmp(key, "separator") == 0 )
+            separator.assign(value);
 
-        else if ( strcmp(i->first, "set_separator") == 0 )
-            set_separator.assign(i->second);
+        else if ( strcmp(key, "set_separator") == 0 )
+            set_separator.assign(value);
 
-        else if ( strcmp(i->first, "empty_field") == 0 )
-            empty_field.assign(i->second);
+        else if ( strcmp(key, "empty_field") == 0 )
+            empty_field.assign(value);
 
-        else if ( strcmp(i->first, "unset_field") == 0 )
-            unset_field.assign(i->second);
+        else if ( strcmp(key, "unset_field") == 0 )
+            unset_field.assign(value);
 
-        else if ( strcmp(i->first, "meta_prefix") == 0 )
-            meta_prefix.assign(i->second);
+        else if ( strcmp(key, "meta_prefix") == 0 )
+            meta_prefix.assign(value);
 
-        else if ( strcmp(i->first, "json_timestamps") == 0 )
-            json_timestamps.assign(i->second);
+        else if ( strcmp(key, "json_timestamps") == 0 )
+            json_timestamps.assign(value);
 
-        else if ( strcmp(i->first, "json_include_unset_fields") == 0 ) {
-            if ( strcmp(i->second, "T") == 0 )
+        else if ( strcmp(key, "json_include_unset_fields") == 0 ) {
+            if ( strcmp(value, "T") == 0 )
                 json_include_unset_fields = true;
-            else if ( strcmp(i->second, "F") == 0 )
+            else if ( strcmp(value, "F") == 0 )
                 json_include_unset_fields = false;
             else {
                 Error(
@@ -339,8 +339,8 @@ bool Ascii::InitFilterOptions() {
             }
         }
 
-        else if ( strcmp(i->first, "gzip_file_extension") == 0 )
-            gzip_file_extension.assign(i->second);
+        else if ( strcmp(key, "gzip_file_extension") == 0 )
+            gzip_file_extension.assign(value);
     }
 
     if ( ! InitFormatter() )
@@ -361,6 +361,8 @@ bool Ascii::InitFormatter() {
             tf = threading::formatter::JSON::TS_EPOCH;
         else if ( strcmp(json_timestamps.c_str(), "JSON::TS_MILLIS") == 0 )
             tf = threading::formatter::JSON::TS_MILLIS;
+        else if ( strcmp(json_timestamps.c_str(), "JSON::TS_MILLIS_UNSIGNED") == 0 )
+            tf = threading::formatter::JSON::TS_MILLIS_UNSIGNED;
         else if ( strcmp(json_timestamps.c_str(), "JSON::TS_ISO8601") == 0 )
             tf = threading::formatter::JSON::TS_ISO8601;
         else {
@@ -436,7 +438,7 @@ bool Ascii::DoInit(const WriterInfo& info, int num_fields, const threading::Fiel
         }
 
         if ( fname.front() != '/' && ! logdir.empty() )
-            fname = (zeek::filesystem::path(logdir) / fname).string();
+            fname = (std::filesystem::path(logdir) / fname).string();
 
         fname += ext;
 
@@ -586,7 +588,7 @@ bool Ascii::DoWrite(int num_fields, const threading::Field* const* fields, threa
     desc.AddRaw("\n", 1);
 
     const char* bytes = (const char*)desc.Bytes();
-    int len = desc.Len();
+    size_t len = desc.Size();
 
     if ( strncmp(bytes, meta_prefix.data(), meta_prefix.size()) == 0 ) {
         // It would so escape the first character.
@@ -662,11 +664,6 @@ bool Ascii::DoSetBuf(bool enabled) {
     return true;
 }
 
-bool Ascii::DoHeartbeat(double network_time, double current_time) {
-    // Nothing to do.
-    return true;
-}
-
 static std::vector<LeftoverLog> find_leftover_logs() {
     std::vector<LeftoverLog> rval;
     std::vector<std::string> stale_shadow_files;
@@ -675,10 +672,10 @@ static std::vector<LeftoverLog> find_leftover_logs() {
 
     // Find any .shadow files within Log::default_logdir or otherwise search in
     // the current working directory.
-    auto logdir = zeek::filesystem::current_path();
+    auto logdir = std::filesystem::current_path();
 
     if ( ! default_logdir.empty() )
-        logdir = zeek::filesystem::absolute(default_logdir);
+        logdir = std::filesystem::absolute(default_logdir);
 
     auto d = opendir(logdir.string().c_str());
     struct dirent* dp;
