@@ -3,18 +3,20 @@
 #include "zeek/spicy/runtime-support.h"
 
 #include <memory>
+#include <ranges>
 
 #include <hilti/rt/exception.h>
 #include <hilti/rt/profiler.h>
 #include <hilti/rt/types/port.h>
 #include <hilti/rt/util.h>
 
-#include "net_util.h"
 #include "zeek/Event.h"
 #include "zeek/analyzer/Manager.h"
 #include "zeek/analyzer/protocol/pia/PIA.h"
 #include "zeek/file_analysis/File.h"
 #include "zeek/file_analysis/Manager.h"
+#include "zeek/net_util.h"
+#include "zeek/packet_analysis/Manager.h"
 #include "zeek/spicy/manager.h"
 
 using namespace zeek;
@@ -29,20 +31,21 @@ void rt::register_spicy_module_end() { spicy_mgr->registerSpicyModuleEnd(); }
 void rt::register_protocol_analyzer(const std::string& name, hilti::rt::Protocol proto,
                                     const hilti::rt::Vector<::zeek::spicy::rt::PortRange>& ports,
                                     const std::string& parser_orig, const std::string& parser_resp,
-                                    const std::string& replaces, const std::string& linker_scope) {
+                                    const std::string& replaces,
+                                    const hilti::rt::integer::safe<uint64_t>& linker_scope) {
     auto _ = hilti::rt::profiler::start("zeek/rt/register_protocol_analyzer");
     spicy_mgr->registerProtocolAnalyzer(name, proto, ports, parser_orig, parser_resp, replaces, linker_scope);
 }
 
 void rt::register_file_analyzer(const std::string& name, const hilti::rt::Vector<std::string>& mime_types,
                                 const std::string& parser, const std::string& replaces,
-                                const std::string& linker_scope) {
+                                const hilti::rt::integer::safe<uint64_t>& linker_scope) {
     auto _ = hilti::rt::profiler::start("zeek/rt/register_file_analyzer");
     spicy_mgr->registerFileAnalyzer(name, mime_types, parser, replaces, linker_scope);
 }
 
 void rt::register_packet_analyzer(const std::string& name, const std::string& parser, const std::string& replaces,
-                                  const std::string& linker_scope) {
+                                  const hilti::rt::integer::safe<uint64_t>& linker_scope) {
     auto _ = hilti::rt::profiler::start("zeek/rt/register_packet_analyzer");
     spicy_mgr->registerPacketAnalyzer(name, parser, replaces, linker_scope);
 }
@@ -106,6 +109,17 @@ std::string hilti::rt::detail::adl::to_string(const zeek::spicy::rt::ZeekTypeTag
     return type_name(zeekTypeForTag(v));
 }
 
+std::string hilti::rt::detail::adl::to_string(const zeek::spicy::rt::AnalyzerType& v, detail::adl::tag /* unused */) {
+    switch ( v.value() ) {
+        case zeek::spicy::rt::AnalyzerType::File: return "AnalyzerType::File";
+        case zeek::spicy::rt::AnalyzerType::Packet: return "AnalyzerType::Packet";
+        case zeek::spicy::rt::AnalyzerType::Protocol: return "AnalyzerType::Protocol";
+        case zeek::spicy::rt::AnalyzerType::Undef: return "AnalyzerType::Undef";
+    }
+
+    hilti::rt::cannot_be_reached();
+}
+
 TypePtr rt::create_enum_type(
     const std::string& ns, const std::string& id,
     const hilti::rt::Set<std::tuple<std::optional<std::string>, std::optional<hilti::rt::integer::safe<int64_t>>>>&
@@ -236,7 +250,7 @@ zeek::analyzer::ID rt::current_analyzer_id() {
         if ( auto x = cookie->protocol ) {
             return x->analyzer->GetID();
         }
-        else if ( auto x = cookie->file ) {
+        else if ( auto x = cookie->file ) { // NOLINT(bugprone-branch-clone)
             return 0;
         }
         else if ( auto x = cookie->packet ) {
@@ -513,6 +527,25 @@ void rt::weird(const std::string& id, const std::string& addl) {
     throw ValueUnavailable("none of $conn, $file, or $packet available for weird reporting");
 }
 
+rt::AnalyzerType rt::analyzer_type(const std::string& analyzer, const hilti::rt::Bool& if_enabled) {
+    if ( auto* c = file_mgr->Lookup(analyzer.c_str()) ) {
+        if ( (! if_enabled) || c->Enabled() )
+            return AnalyzerType::File;
+    }
+
+    if ( auto* c = packet_mgr->Lookup(analyzer.c_str()) ) {
+        if ( (! if_enabled) || c->Enabled() )
+            return AnalyzerType::Packet;
+    }
+
+    if ( auto* c = analyzer_mgr->Lookup(analyzer.c_str()) ) {
+        if ( (! if_enabled) || c->Enabled() )
+            return AnalyzerType::Protocol;
+    }
+
+    return AnalyzerType::Undef;
+}
+
 void rt::protocol_begin(const std::optional<std::string>& analyzer, const ::hilti::rt::Protocol& proto) {
     auto _ = hilti::rt::profiler::start("zeek/rt/protocol_begin");
 
@@ -885,9 +918,9 @@ const rt::cookie::FileState* rt::cookie::FileStateStack::find(const std::string&
     auto _ = hilti::rt::profiler::start("zeek/rt/file-stack-find");
 
     // Reverse search as the default state would be on top of the stack.
-    for ( auto i = _stack.rbegin(); i != _stack.rend(); i++ ) {
-        if ( i->fid == fid )
-            return &*i;
+    for ( const auto& i : std::ranges::reverse_view(_stack) ) {
+        if ( i.fid == fid )
+            return &i;
     }
 
     return nullptr;
