@@ -1,3 +1,4 @@
+
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #pragma once
@@ -15,7 +16,7 @@ class [[nodiscard]] Timer {
 public:
     using Clock = std::chrono::steady_clock;
 
-    explicit Timer(DblHistogram h) : h_(h) { start_ = Clock::now(); }
+    explicit Timer(std::shared_ptr<Histogram> h) : h_(std::move(h)) { start_ = Clock::now(); }
 
     Timer(const Timer&) = delete;
 
@@ -30,14 +31,14 @@ public:
     auto Started() const noexcept { return start_; }
 
     /// Calls `h.Observe` with the time passed since `start`.
-    static void Observe(DblHistogram h, Clock::time_point start) {
-        using DblSec = std::chrono::duration<double>;
+    static void Observe(const std::shared_ptr<Histogram>& h, Clock::time_point start) {
+        using Sec = std::chrono::duration<double>;
         if ( auto end = Clock::now(); end > start )
-            h.Observe(std::chrono::duration_cast<DblSec>(end - start).count());
+            h->Observe(std::chrono::duration_cast<Sec>(end - start).count());
     }
 
 private:
-    DblHistogram h_;
+    std::shared_ptr<Histogram> h_;
     Clock::time_point start_;
 };
 
